anjuta r3490 - in trunk: . libanjuta/interfaces manuals/reference/libanjuta plugins/debug-manager plugins/gdb



Author: sgranjoux
Date: Fri Jan 18 20:40:36 2008
New Revision: 3490
URL: http://svn.gnome.org/viewvc/anjuta?rev=3490&view=rev

Log:
	* plugins/debug-manager/disassemble.c,
	plugins/debug-manager/disassemble.h,
	plugins/debug-manager/registers.c,
	plugins/debug-manager/registers.h,
	plugins/debug-manager/memory.c,
	plugins/debug-manager/memory.h,
	plugins/debug-manager/command.c,
	plugins/debug-manager/command.h,
	plugins/debug-manager/queue.c,
	plugins/debug-manager/queue.h,
	plugins/debug-manager/breakpoints.c,
	plugins/debug-manager/stack_trace.c,
	plugins/debug-manager/threads.c,
	plugins/debug-manager/plugin.c,
	plugins/gdb/plugin.c,
	plugins/gdb/debugger.c,
	plugins/gdb/debugger.h,
	manuals/reference/libanjuta/libanjuta-sections.txt,
	manuals/reference/libanjuta/libanjuta.types,
	libanjuta/interfaces/libanjuta.idl:
	Use gulong instead of guint for addresses
	Split IAnjutaCpuDebugger interface in IAnjutaDebuggerRegister,
	IAnjutaDebuggerMemory and IAnjutaDebuggerInstruction

	* plugins/gdb/anjuta-gdb.plugin.in:
	Remove reference to IAnjutaCpuDebugger (useless)


Modified:
   trunk/ChangeLog
   trunk/libanjuta/interfaces/libanjuta.idl
   trunk/manuals/reference/libanjuta/libanjuta-sections.txt
   trunk/manuals/reference/libanjuta/libanjuta.types
   trunk/plugins/debug-manager/breakpoints.c
   trunk/plugins/debug-manager/command.c
   trunk/plugins/debug-manager/command.h
   trunk/plugins/debug-manager/disassemble.c
   trunk/plugins/debug-manager/disassemble.h
   trunk/plugins/debug-manager/memory.c
   trunk/plugins/debug-manager/memory.h
   trunk/plugins/debug-manager/plugin.c
   trunk/plugins/debug-manager/queue.c
   trunk/plugins/debug-manager/queue.h
   trunk/plugins/debug-manager/registers.c
   trunk/plugins/debug-manager/registers.h
   trunk/plugins/debug-manager/stack_trace.c
   trunk/plugins/debug-manager/threads.c
   trunk/plugins/gdb/anjuta-gdb.plugin.in
   trunk/plugins/gdb/debugger.c
   trunk/plugins/gdb/debugger.h
   trunk/plugins/gdb/plugin.c

Modified: trunk/libanjuta/interfaces/libanjuta.idl
==============================================================================
--- trunk/libanjuta/interfaces/libanjuta.idl	(original)
+++ trunk/libanjuta/interfaces/libanjuta.idl	Fri Jan 18 20:40:36 2008
@@ -2867,13 +2867,6 @@
 		PROGRAM_RUNNING
 	}
 
-	struct Register
-	{
-		guint num;
-		gchar *name;
-		gchar *value;
-	}
-
 	struct Frame
 	{
 		gint thread;
@@ -2883,36 +2876,15 @@
 		guint line;
 		gchar *function;
 		gchar *library;
-		guint address;
-	}
-
-	struct Memory
-	{
-		guint address;
-		guint length;
-		gchar *data;
+		gulong address;
 	}
 
-
-	struct ALine
-	{
-		guint address;
-		const gchar *label;
-		const gchar *text;
-	}
-
-	struct Disassembly
-	{
-		guint size;
-		ALine data[];	
-	}	
-
 	/* Call back functions */
 	typedef void (*Callback) (const gpointer data, gpointer user_data, GError* err);
 	typedef void (*GListCallback) (const GList* list, gpointer user_data, GError* err);
 	typedef void (*GCharCallback) (const gchar *value, gpointer user_data, GError* err);
 	typedef void (*OutputCallback) (OutputType type, const gchar *output, gpointer user_data);
-	typedef void (*MemoryCallback) (const gchar* address, guint length, const gchar *data, gpointer user_data, GError *err);
+	typedef void (*MemoryCallback) (gulong address, guint length, const gchar *data, gpointer user_data, GError *err);
 
 	/* Signals */
 
@@ -2986,7 +2958,7 @@
 	* location. Most of the time, after the program has stopped but it
 	* could happen even if it is still running.
 	*/
-	void ::program_moved (gint pid, gint tid, guint address, const gchar* file, guint line);
+	void ::program_moved (gint pid, gint tid, gulong address, const gchar* file, guint line);
 
 	/**
 	* IAnjutaDebugger::frame_changed:
@@ -3538,7 +3510,7 @@
 			gchar *file;
 			guint line;
 			gchar *function;
-			guint address;
+			gulong address;
 			gboolean enable;
 			guint ignore;
 			guint times;
@@ -3598,7 +3570,7 @@
 		* Returns: TRUE if the request succeed and the callback is called. If 
 		* FALSE, the callback will not be called.
 		*/
-		gboolean set_at_address (guint address, IAnjutaDebuggerCallback callback, gpointer user_data);
+		gboolean set_at_address (gulong address, IAnjutaDebuggerCallback callback, gpointer user_data);
 	
 		/**
 		* ianjuta_debugger_breakpoint_set_at_function:
@@ -3715,10 +3687,6 @@
 	*/
 	interface IAnjutaDebuggerVariable
 	{
-		#include "ianjuta-debug-manager.h"
-		#include "ianjuta-debugger.h"
-		#include <sys/types.h>
-
 		struct Object
 		{
 			gchar *name;
@@ -3819,130 +3787,187 @@
 		*/
 		gboolean destroy (const gchar *name);
 	}
-}
-
-/**
- * SECTION:ianjuta-cpu-debugger
- * @title: IAnjutaCpuDebugger
- * @short_description: CPU specific debugger interface
- * @see_also: 
- * @stability: Unstable
- * @include: libanjuta/interfaces/ianjuta-cpu-debugger.h
- * 
- */
-interface IAnjutaCpuDebugger
-{
-	#include "ianjuta-debug-manager.h"
-	#include "ianjuta-debugger.h"
-	#include "ianjuta-message-view.h"
-	#include <sys/types.h>
-
+	
 	/**
-	* ianjuta_debugger_list_register:
-	* @obj: Self
-	* @callback: fixme
-	* @user_data: fixme
-	* @err: Error propagation and reporting.
+	* SECTION:ianjuta-debugger-register
+	* @title: IAnjutaDebuggerRegister
+	* @short_description: Register interface for debuggers
+	* @see_also: 
+	* @stability: Unstable
+	* @include: libanjuta/interfaces/ianjuta-debugger-register.h
 	* 
-	* fixme
-	*
-	* Returns: fixme
+ 	* This interface is used to examine and change values of CPU registers.
 	*/
-	gboolean list_register (IAnjutaDebuggerCallback callback, gpointer user_data);
+	interface IAnjutaDebuggerRegister
+	{
 
-	/**
-	* ianjuta_debugger_update_register:
-	* @obj: Self
-	* @callback: fixme
-	* @user_data: fixme
-	* @err: Error propagation and reporting.
-	* 
-	* fixme
-	*
-	* Returns: fixme
-	*/
-	gboolean update_register (IAnjutaDebuggerCallback callback, gpointer user_data);
+		struct Data
+		{
+			guint num;
+			gchar *name;
+			gchar *value;
+		}
 
-	/**
-	* ianjuta_debugger_write_register:
-	* @obj: Self
-	* @value: fixme
-	* @err: Error propagation and reporting.
-	* 
-	* fixme
-	*
-	* Returns: fixme
-	*/
-	gboolean write_register (IAnjutaDebuggerRegister *value);
+		/**
+		* ianjuta_debugger_register_list:
+		* @obj: Self
+		* @callback: Callback to call with the register list
+		* @user_data: User data that is passed back to the callback
+		* @err: Error propagation and reporting.
+		* 
+		* List all registers of the target. This function can be called without
+		* a program loaded, the value field of register structure is not filled.
+		*
+		* Returns: TRUE if the request succeed and the callback is
+		* called. If FALSE, the callback will not be called.
+		*/
+		gboolean list (IAnjutaDebuggerCallback callback, gpointer user_data);
 
-	/**
-	* ianjuta_debugger_inspect_memory:
-	* @obj: Self
-	* @address: fixme
-	* @length: fixme
-	* @callback: fixme
-	* @user_data: fixme
-	* @err: Error propagation and reporting.
-	* 
-	* fixme
-	*
-	* Returns: fixme
-	*/
-	gboolean inspect_memory (guint address, guint length, IAnjutaDebuggerCallback callback, gpointer user_data);
+		/**
+		* ianjuta_debugger_register_update:
+		* @obj: Self
+		* @callback: Callback call with the list of all modified registers
+		* @user_data: User data that is passed back to the callback
+		* @err: Error propagation and reporting.
+		* 
+		* Return all modified registers since the last call. Only the num and
+		* value field are used.
+		*
+		* Returns: TRUE if the request succeed and the callback is
+		* called. If FALSE, the callback will not be called.
+		*/
+		gboolean update (IAnjutaDebuggerCallback callback, gpointer user_data);
 
+		/**
+		* ianjuta_debugger_register_write:
+		* @obj: Self
+		* @value: Modified register with a new value
+		* @err: Error propagation and reporting.
+		* 
+		* Change the value of one register. Only the num and value field are used.
+		*
+		* Returns: TRUE if the request succeed.
+		*/
+		gboolean write (Data *value);
+	}
+	
 	/**
-	* ianjuta_debugger_disassemble:
-	* @obj: Self
-	* @address: fixme
-	* @length: fixme
-	* @callback: fixme
-	* @user_data: fixme
-	* @err: Error propagation and reporting.
+	* SECTION:ianjuta-debugger-memory
+	* @title: IAnjutaDebuggerMemory
+	* @short_description: Memory interface for debuggers
+	* @see_also: 
+	* @stability: Unstable
+	* @include: libanjuta/interfaces/ianjuta-debugger-memory.h
 	* 
-	* Disassemble a part of the memory
-	*
-	* Returns: TRUE if sucessful else FALSE and check err to get more
-	*          detail.
+ 	* This interface is used to examine the target memory.
 	*/
-	gboolean disassemble (guint address, guint length, IAnjutaDebuggerCallback callback, gpointer user_data);
+	interface IAnjutaDebuggerMemory
+	{
+		struct Block
+		{
+			gulong address;
+			guint length;
+			gchar *data;
+		}
+
+		/**
+		* ianjuta_debugger_memory_inspect:
+		* @obj: Self
+		* @address: Start address of the memory block
+		* @length: Length of memory block
+		* @callback: Call back with a IAnjutaDebuggerMemoryBlock as argument
+		* @user_data: User data that is passed back to the callback
+		* @err: Error propagation and reporting.
+		* 
+		* Read a block of the target memory.
+		*
+		* Returns: TRUE if the request succeed and the callback is
+		* called. If FALSE, the callback will not be called.
+		*/
+		gboolean inspect (gulong address, guint length, IAnjutaDebuggerCallback callback, gpointer user_data);
+	}
 
 	/**
-	* ianjuta_debugger_stepi_in:
-	* @obj: Self
-	* @err: Error propagation and reporting.
+	* SECTION:ianjuta-debugger-instruction
+	* @title: IAnjutaDebuggerInstruction
+	* @short_description: Debugger interface for machine instruction
+	* @see_also: 
+	* @stability: Unstable
+	* @include: libanjuta/interfaces/ianjuta-debugger-instruction.h
 	* 
-	* Execute one assembler instruction in the program.
-	*
-	* Returns: TRUE if the request succeed and the callback is called. If 
-	* FALSE, the callback will not be called.
+ 	* This interface is used to debuger as machine instruction level.
 	*/
-	gboolean stepi_in ();
+	interface IAnjutaDebuggerInstruction
+	{
 	
-	/**
-	* ianjuta_debugger_stepi_over:
-	* @obj: Self
-	* @err: Error propagation and reporting.
-	* 
-	* Execute one assembler instruction in the program, if the instruction
-	* is a function call, continues until the function returns.
-	*
-	* Returns: TRUE if the request succeed and the callback is called. If 
-	* FALSE, the callback will not be called.
-	*/
-	gboolean stepi_over ();
+		struct ALine
+		{
+			gulong address;
+			const gchar *label;
+			const gchar *text;
+		}
+
+		struct Disassembly
+		{
+			guint size;
+			ALine data[];	
+		}	
+
+		/**
+		* ianjuta_debugger_instruction_disassemble:
+		* @obj: Self
+		* @address: Start address of the memory block
+		* @length: Length of memory block
+		* @callback: Call back with a IAnjutaDebuggerInstructionDisassembly as argument
+		* @user_data: User data that is passed back to the callback
+		* @err: Error propagation and reporting.
+		* 
+		* Disassemble a part of the memory
+		*
+		* Returns: TRUE if the request succeed and the callback is
+		* called. If FALSE, the callback will not be called.
+		*/
+		gboolean disassemble (gulong address, guint length, IAnjutaDebuggerCallback callback, gpointer user_data);
+
+		/**
+		* ianjuta_debugger_instruction_step_in:
+		* @obj: Self
+		* @err: Error propagation and reporting.
+		* 
+		* Execute one assembler instruction in the program.
+		*
+		* Returns: TRUE if the request succeed and the callback is called. If 
+		* FALSE, the callback will not be called.
+		*/
+		gboolean step_in ();
 	
-	/**
-	* ianjuta_debugger_run_to_address:
-	* @obj: Self
-	* @address: Run to this addresss
-	* @err: Error propagation and reporting.
-	* 
-	* Start the program until it reachs the address address
-	*
-	* Returns: TRUE if the request succeed and the callback is called. If 
-	* FALSE, the callback will not be called.
-	*/
-	gboolean run_to_address (guint address);
+		/**
+		* ianjuta_debugger_instruction_step_over:
+		* @obj: Self
+		* @err: Error propagation and reporting.
+		* 
+		* Execute one assembler instruction in the program, if the instruction
+		* is a function call, continues until the function returns.
+		*
+		* Returns: TRUE if the request succeed and the callback is called. If 
+		* FALSE, the callback will not be called.
+		*/
+		gboolean step_over ();
+	
+		/**
+		* ianjuta_debugger_instruction_run_to_address:
+		* @obj: Self
+		* @address: Run to this addresss
+		* @err: Error propagation and reporting.
+		* 
+		* Start the program until it reachs the address address
+		*
+		* Returns: TRUE if the request succeed and the callback is called. If 
+		* FALSE, the callback will not be called.
+		*/
+		gboolean run_to_address (gulong address);
+	}
+		
 }
 
 interface IAnjutaDebugManager
@@ -4049,7 +4074,7 @@
 	* location. Most of the time, after the program has stopped but it
 	* could happen even if it is still running.
 	*/
-	void ::program_moved (gint pid, gint tid, guint address, const gchar* file, guint line);
+	void ::program_moved (gint pid, gint tid, gulong address, const gchar* file, guint line);
 
 	/**
 	* IAnjutaDebugManager::frame_changed:
@@ -4076,7 +4101,7 @@
 	* equal to the program location when the program stops but can be
 	* changed afterward by the user.
 	*/
-	void ::location_changed (guint address, const gchar* uri, guint line);	
+	void ::location_changed (gulong address, const gchar* uri, guint line);	
 
 	/**
 	* IAnjutaDebugManager::signal_received:

Modified: trunk/manuals/reference/libanjuta/libanjuta-sections.txt
==============================================================================
--- trunk/manuals/reference/libanjuta/libanjuta-sections.txt	(original)
+++ trunk/manuals/reference/libanjuta/libanjuta-sections.txt	Fri Jan 18 20:40:36 2008
@@ -74,6 +74,7 @@
 anjuta_status_disable_splash
 anjuta_status_progress_add_ticks
 anjuta_status_progress_tick
+anjuta_status_progress_pulse
 anjuta_status_progress_reset
 <SUBSECTION Standard>
 ANJUTA_STATUS
@@ -85,42 +86,6 @@
 </SECTION>
 
 <SECTION>
-<FILE>anjuta-plugin-handle</FILE>
-AnjutaPluginHandlePriv
-<TITLE>AnjutaPluginHandle</TITLE>
-AnjutaPluginHandle
-anjuta_plugin_handle_new
-anjuta_plugin_handle_get_id
-anjuta_plugin_handle_get_name
-anjuta_plugin_handle_get_about
-anjuta_plugin_handle_get_icon_path
-anjuta_plugin_handle_get_path
-anjuta_plugin_handle_get_user_activatable
-anjuta_plugin_handle_get_resident
-anjuta_plugin_handle_get_language
-anjuta_plugin_handle_get_description
-anjuta_plugin_handle_get_dependency_names
-anjuta_plugin_handle_get_dependencies
-anjuta_plugin_handle_get_dependents
-anjuta_plugin_handle_get_interfaces
-anjuta_plugin_handle_get_can_load
-anjuta_plugin_handle_get_checked
-anjuta_plugin_handle_get_resolve_pass
-anjuta_plugin_handle_set_can_load
-anjuta_plugin_handle_set_checked
-anjuta_plugin_handle_set_resolve_pass
-anjuta_plugin_handle_unresolve_dependencies
-<SUBSECTION Standard>
-ANJUTA_PLUGIN_HANDLE
-ANJUTA_IS_PLUGIN_HANDLE
-ANJUTA_TYPE_PLUGIN_HANDLE
-anjuta_plugin_handle_get_type
-ANJUTA_PLUGIN_HANDLE_CLASS
-ANJUTA_IS_PLUGIN_HANDLE_CLASS
-ANJUTA_PLUGIN_HANDLE_GET_CLASS
-</SECTION>
-
-<SECTION>
 <FILE>cell-renderer-captioned-image</FILE>
 <TITLE>AnjutaCellRendererCaptionedImage</TITLE>
 AnjutaCellRendererCaptionedImage
@@ -136,34 +101,6 @@
 </SECTION>
 
 <SECTION>
-<FILE>anjuta-plugin</FILE>
-AnjutaGluePlugin
-AnjutaPluginPrivate
-AnjutaPluginValueAdded
-AnjutaPluginValueRemoved
-<TITLE>AnjutaPlugin</TITLE>
-AnjutaPlugin
-anjuta_plugin_activate
-anjuta_plugin_deactivate
-anjuta_plugin_is_active
-anjuta_plugin_add_watch
-anjuta_plugin_remove_watch
-ANJUTA_PLUGIN_BEGIN
-ANJUTA_PLUGIN_END
-ANJUTA_PLUGIN_ADD_INTERFACE
-ANJUTA_PLUGIN_BOILERPLATE
-ANJUTA_SIMPLE_PLUGIN
-<SUBSECTION Standard>
-ANJUTA_PLUGIN
-ANJUTA_IS_PLUGIN
-ANJUTA_TYPE_PLUGIN
-anjuta_plugin_get_type
-ANJUTA_PLUGIN_CLASS
-ANJUTA_IS_PLUGIN_CLASS
-ANJUTA_PLUGIN_GET_CLASS
-</SECTION>
-
-<SECTION>
 <FILE>e-splash</FILE>
 ESplashPrivate
 <TITLE>ESplash</TITLE>
@@ -198,41 +135,6 @@
 </SECTION>
 
 <SECTION>
-<FILE>anjuta-plugin-manager</FILE>
-ANJUTA_PLUGIN_MANAGER_ERROR
-AnjutaPluginManagerError
-AnjutaPluginManagerPriv
-<TITLE>AnjutaPluginManager</TITLE>
-AnjutaPluginManager
-anjuta_plugin_manager_error_quark
-anjuta_plugin_manager_new
-anjuta_plugin_manager_get_plugin
-anjuta_plugin_manager_get_plugin_by_id
-anjuta_plugin_manager_unload_plugin
-anjuta_plugin_manager_unload_plugin_by_id
-anjuta_plugin_manager_get_active_plugins
-anjuta_plugin_manager_get_active_plugin_objects
-anjuta_plugin_manager_get_plugins_page
-anjuta_plugin_manager_get_remembered_plugins_page
-anjuta_plugin_manager_query
-anjuta_plugin_manager_select
-anjuta_plugin_manager_select_and_activate
-anjuta_plugin_manager_activate_plugins
-anjuta_plugin_manager_unload_all_plugins
-anjuta_plugin_manager_get_remembered_plugins
-anjuta_plugin_manager_set_remembered_plugins
-anjuta_plugin_manager_get_interface
-<SUBSECTION Standard>
-ANJUTA_PLUGIN_MANAGER
-ANJUTA_IS_PLUGIN_MANAGER
-ANJUTA_TYPE_PLUGIN_MANAGER
-anjuta_plugin_manager_get_type
-ANJUTA_PLUGIN_MANAGER_CLASS
-ANJUTA_IS_PLUGIN_MANAGER_CLASS
-ANJUTA_PLUGIN_MANAGER_GET_CLASS
-</SECTION>
-
-<SECTION>
 <FILE>anjuta-shell</FILE>
 ANJUTA_SHELL_ERROR
 AnjutaShell
@@ -322,51 +224,6 @@
 </SECTION>
 
 <SECTION>
-<FILE>anjuta-c-module</FILE>
-<TITLE>AnjutaCModule</TITLE>
-AnjutaCModule
-AnjutaCModuleClass
-anjuta_c_module_new
-anjuta_c_module_get_last_error
-<SUBSECTION Standard>
-ANJUTA_C_MODULE
-ANJUTA_IS_C_MODULE
-ANJUTA_TYPE_C_MODULE
-anjuta_c_module_get_type
-ANJUTA_C_MODULE_CLASS
-ANJUTA_IS_C_MODULE_CLASS
-ANJUTA_C_MODULE_GET_CLASS
-</SECTION>
-
-<SECTION>
-<FILE>anjuta-profile</FILE>
-ANJUTA_PROFILE_ERROR
-AnjutaProfileError
-AnjutaProfilePriv
-<TITLE>AnjutaProfile</TITLE>
-AnjutaProfile
-anjuta_profile_error_quark
-anjuta_profile_new
-anjuta_profile_get_name
-anjuta_profile_add_plugin
-anjuta_profile_remove_plugin
-anjuta_profile_add_plugins_from_xml
-anjuta_profile_has_plugin
-anjuta_profile_get_plugins
-anjuta_profile_to_xml
-anjuta_profile_set_sync_uri
-anjuta_profile_sync
-<SUBSECTION Standard>
-ANJUTA_PROFILE
-ANJUTA_IS_PROFILE
-ANJUTA_TYPE_PROFILE
-anjuta_profile_get_type
-ANJUTA_PROFILE_CLASS
-ANJUTA_IS_PROFILE_CLASS
-ANJUTA_PROFILE_GET_CLASS
-</SECTION>
-
-<SECTION>
 <FILE>anjuta-preferences</FILE>
 AnjutaPropertyObjectType
 AnjutaPropertyDataType
@@ -440,6 +297,7 @@
 anjuta_launcher_set_check_passwd_prompt
 anjuta_launcher_set_terminal_echo
 anjuta_launcher_set_terminate_on_exit
+anjuta_launcher_disable_password_check
 <SUBSECTION Standard>
 ANJUTA_LAUNCHER
 ANJUTA_IS_LAUNCHER
@@ -450,6 +308,169 @@
 </SECTION>
 
 <SECTION>
+<FILE>anjuta-c-module</FILE>
+AnjutaCModule
+AnjutaCModuleClass
+anjuta_c_module_new
+anjuta_c_module_get_last_error
+<SUBSECTION Standard>
+ANJUTA_C_MODULE
+ANJUTA_IS_C_MODULE
+ANJUTA_TYPE_C_MODULE
+anjuta_c_module_get_type
+ANJUTA_C_MODULE_CLASS
+ANJUTA_IS_C_MODULE_CLASS
+ANJUTA_C_MODULE_GET_CLASS
+</SECTION>
+
+<SECTION>
+<FILE>anjuta-plugin</FILE>
+AnjutaGluePlugin
+AnjutaPluginPrivate
+AnjutaPluginValueAdded
+AnjutaPluginValueRemoved
+<TITLE>AnjutaPlugin</TITLE>
+AnjutaPlugin
+anjuta_plugin_activate
+anjuta_plugin_deactivate
+anjuta_plugin_is_active
+anjuta_plugin_add_watch
+anjuta_plugin_remove_watch
+ANJUTA_PLUGIN_BEGIN
+ANJUTA_PLUGIN_END
+ANJUTA_PLUGIN_ADD_INTERFACE
+ANJUTA_PLUGIN_BOILERPLATE
+ANJUTA_SIMPLE_PLUGIN
+<SUBSECTION Standard>
+ANJUTA_PLUGIN
+ANJUTA_IS_PLUGIN
+ANJUTA_TYPE_PLUGIN
+anjuta_plugin_get_type
+ANJUTA_PLUGIN_CLASS
+ANJUTA_IS_PLUGIN_CLASS
+ANJUTA_PLUGIN_GET_CLASS
+</SECTION>
+
+<SECTION>
+<FILE>anjuta-command</FILE>
+AnjutaCommandPriv
+<TITLE>AnjutaCommand</TITLE>
+AnjutaCommand
+anjuta_command_start
+anjuta_command_notify_data_arrived
+anjuta_command_notify_complete
+anjuta_command_set_error_message
+anjuta_command_get_error_message
+<SUBSECTION Standard>
+ANJUTA_COMMAND
+ANJUTA_IS_COMMAND
+ANJUTA_TYPE_COMMAND
+anjuta_command_get_type
+ANJUTA_COMMAND_CLASS
+ANJUTA_IS_COMMAND_CLASS
+ANJUTA_COMMAND_GET_CLASS
+</SECTION>
+
+<SECTION>
+<FILE>anjuta-plugin-handle</FILE>
+AnjutaPluginHandlePriv
+<TITLE>AnjutaPluginHandle</TITLE>
+AnjutaPluginHandle
+anjuta_plugin_handle_new
+anjuta_plugin_handle_get_id
+anjuta_plugin_handle_get_name
+anjuta_plugin_handle_get_about
+anjuta_plugin_handle_get_icon_path
+anjuta_plugin_handle_get_path
+anjuta_plugin_handle_get_user_activatable
+anjuta_plugin_handle_get_resident
+anjuta_plugin_handle_get_language
+anjuta_plugin_handle_get_description
+anjuta_plugin_handle_get_dependency_names
+anjuta_plugin_handle_get_dependencies
+anjuta_plugin_handle_get_dependents
+anjuta_plugin_handle_get_interfaces
+anjuta_plugin_handle_get_can_load
+anjuta_plugin_handle_get_checked
+anjuta_plugin_handle_get_resolve_pass
+anjuta_plugin_handle_set_can_load
+anjuta_plugin_handle_set_checked
+anjuta_plugin_handle_set_resolve_pass
+anjuta_plugin_handle_unresolve_dependencies
+<SUBSECTION Standard>
+ANJUTA_PLUGIN_HANDLE
+ANJUTA_IS_PLUGIN_HANDLE
+ANJUTA_TYPE_PLUGIN_HANDLE
+anjuta_plugin_handle_get_type
+ANJUTA_PLUGIN_HANDLE_CLASS
+ANJUTA_IS_PLUGIN_HANDLE_CLASS
+ANJUTA_PLUGIN_HANDLE_GET_CLASS
+</SECTION>
+
+<SECTION>
+<FILE>anjuta-plugin-manager</FILE>
+ANJUTA_PLUGIN_MANAGER_ERROR
+AnjutaPluginManagerError
+AnjutaPluginManagerPriv
+<TITLE>AnjutaPluginManager</TITLE>
+AnjutaPluginManager
+anjuta_plugin_manager_error_quark
+anjuta_plugin_manager_new
+anjuta_plugin_manager_get_plugin
+anjuta_plugin_manager_get_plugin_by_id
+anjuta_plugin_manager_unload_plugin
+anjuta_plugin_manager_unload_plugin_by_id
+anjuta_plugin_manager_get_active_plugins
+anjuta_plugin_manager_get_active_plugin_objects
+anjuta_plugin_manager_get_plugins_page
+anjuta_plugin_manager_get_remembered_plugins_page
+anjuta_plugin_manager_query
+anjuta_plugin_manager_select
+anjuta_plugin_manager_select_and_activate
+anjuta_plugin_manager_activate_plugins
+anjuta_plugin_manager_unload_all_plugins
+anjuta_plugin_manager_get_remembered_plugins
+anjuta_plugin_manager_set_remembered_plugins
+anjuta_plugin_manager_get_interface
+<SUBSECTION Standard>
+ANJUTA_PLUGIN_MANAGER
+ANJUTA_IS_PLUGIN_MANAGER
+ANJUTA_TYPE_PLUGIN_MANAGER
+anjuta_plugin_manager_get_type
+ANJUTA_PLUGIN_MANAGER_CLASS
+ANJUTA_IS_PLUGIN_MANAGER_CLASS
+ANJUTA_PLUGIN_MANAGER_GET_CLASS
+</SECTION>
+
+<SECTION>
+<FILE>anjuta-profile</FILE>
+ANJUTA_PROFILE_ERROR
+AnjutaProfileError
+AnjutaProfilePriv
+<TITLE>AnjutaProfile</TITLE>
+AnjutaProfile
+anjuta_profile_error_quark
+anjuta_profile_new
+anjuta_profile_get_name
+anjuta_profile_add_plugin
+anjuta_profile_remove_plugin
+anjuta_profile_add_plugins_from_xml
+anjuta_profile_has_plugin
+anjuta_profile_get_plugins
+anjuta_profile_to_xml
+anjuta_profile_set_sync_uri
+anjuta_profile_sync
+<SUBSECTION Standard>
+ANJUTA_PROFILE
+ANJUTA_IS_PROFILE
+ANJUTA_TYPE_PROFILE
+anjuta_profile_get_type
+ANJUTA_PROFILE_CLASS
+ANJUTA_IS_PROFILE_CLASS
+ANJUTA_PROFILE_GET_CLASS
+</SECTION>
+
+<SECTION>
 <FILE>anjuta-profile-manager</FILE>
 AnjutaProfileManagerPriv
 <TITLE>AnjutaProfileManager</TITLE>
@@ -471,8 +492,104 @@
 </SECTION>
 
 <SECTION>
+<FILE>anjuta-glue-code</FILE>
+<TITLE>AnjutaGlueCPlugin</TITLE>
+AnjutaGlueCPlugin
+anjuta_glue_c_plugin_new
+<SUBSECTION Standard>
+ANJUTA_GLUE_C_PLUGIN
+ANJUTA_GLUE_IS_C_PLUGIN
+ANJUTA_GLUE_TYPE_C_PLUGIN
+anjuta_glue_c_plugin_get_type
+ANJUTA_GLUE_C_PLUGIN_CLASS
+ANJUTA_GLUE_IS_C_PLUGIN_CLASS
+ANJUTA_GLUE_C_PLUGIN_GET_CLASS
+</SECTION>
+
+<SECTION>
+<FILE>anjuta-glue-plugin.old</FILE>
+ANJUTA_GLUE_PLUGIN
+AnjutaGluePluginComponent
+AnjutaGluePluginComponentGetTypeFunc
+<TITLE>AnjutaGluePlugin</TITLE>
+AnjutaGluePlugin
+anjuta_glue_plugin_new
+ANJUTA_GLUE_PLUGIN_MODULE
+ANJUTA_GLUE_REGISTER_COMPONENTS
+ANJUTA_GLUE_GET_COMPONENT_TYPE
+<SUBSECTION Standard>
+ANJUTA_TYPE_GLUE_PLUGIN
+ANJUTA_GLUE_IS_PLUGIN
+anjuta_glue_plugin_get_type
+ANJUTA_GLUE_PLUGIN_CLASS
+ANJUTA_GLUE_IS_PLUGIN_CLASS
+ANJUTA_GLUE_PLUGIN_GET_CLASS
+</SECTION>
+
+<SECTION>
+<FILE>anjuta-glue-plugin.old1</FILE>
+AnjutaGluePluginComponent
+AnjutaGluePluginComponentGetTypeFunc
+AnjutaGluePluginGetTypeFunc
+<TITLE>AnjutaGluePlugin</TITLE>
+AnjutaGluePlugin
+anjuta_glue_plugin_new
+anjuta_glue_plugin_set_module_path
+anjuta_glue_plugin_get_component_type
+anjuta_glue_plugin_get_name
+ANJUTA_GLUE_PLUGIN_MODULE
+ANJUTA_GLUE_REGISTER_COMPONENTS
+ANJUTA_GLUE_GET_COMPONENT_TYPE
+<SUBSECTION Standard>
+ANJUTA_GLUE_PLUGIN
+ANJUTA_GLUE_IS_PLUGIN
+ANJUTA_GLUE_TYPE_PLUGIN
+anjuta_glue_plugin_get_type
+ANJUTA_GLUE_PLUGIN_CLASS
+ANJUTA_GLUE_IS_PLUGIN_CLASS
+ANJUTA_GLUE_PLUGIN_GET_CLASS
+</SECTION>
+
+<SECTION>
+<FILE>anjuta-glue-c.old</FILE>
+<TITLE>AnjutaGlueCPlugin</TITLE>
+AnjutaGlueCPlugin
+anjuta_glue_c_plugin_new
+<SUBSECTION Standard>
+ANJUTA_GLUE_C_PLUGIN
+ANJUTA_GLUE_IS_C_PLUGIN
+ANJUTA_GLUE_TYPE_C_PLUGIN
+anjuta_glue_c_plugin_get_type
+ANJUTA_GLUE_C_PLUGIN_CLASS
+ANJUTA_GLUE_IS_C_PLUGIN_CLASS
+ANJUTA_GLUE_C_PLUGIN_GET_CLASS
+</SECTION>
+
+<SECTION>
+<FILE>anjuta-vcs-status-tree-view</FILE>
+ANJUTA_VCS_DEFAULT_STATUS_CODES
+AnjutaVcsStatusTreeViewPriv
+<TITLE>AnjutaVcsStatusTreeView</TITLE>
+AnjutaVcsStatusTreeView
+AnjutaVcsStatus
+anjuta_vcs_status_tree_view_new
+anjuta_vcs_status_tree_view_destroy
+anjuta_vcs_status_tree_view_add
+anjuta_vcs_status_tree_view_select_all
+anjuta_vcs_status_tree_view_unselect_all
+anjuta_vcs_status_tree_view_get_selected
+<SUBSECTION Standard>
+ANJUTA_VCS_STATUS_TREE_VIEW
+ANJUTA_VCS_IS_STATUS_TREE_VIEW
+ANJUTA_VCS_TYPE_STATUS_TREE_VIEW
+anjuta_vcs_status_tree_view_get_type
+ANJUTA_VCS_STATUS_TREE_VIEW_CLASS
+ANJUTA_VCS_IS_STATUS_TREE_VIEW_CLASS
+ANJUTA_VCS_STATUS_TREE_VIEW_GET_CLASS
+</SECTION>
+
+<SECTION>
 <FILE>anjuta-c-plugin-factory</FILE>
-<TITLE>AnjutaCPluginFactory</TITLE>
 AnjutaCPluginFactory
 AnjutaCPluginFactoryClass
 anjuta_c_plugin_factory_new
@@ -494,7 +611,6 @@
 IAnjutaEditorAttribute
 IAnjutaEditorError
 IANJUTA_EDITOR_ERROR
-<TITLE>IAnjutaEditor</TITLE>
 IAnjutaEditor
 IAnjutaEditorIface
 ianjuta_editor_error_get_type
@@ -516,6 +632,7 @@
 ianjuta_editor_get_position_iter
 ianjuta_editor_get_tabsize
 ianjuta_editor_get_text
+ianjuta_editor_get_text_iter
 ianjuta_editor_get_use_spaces
 ianjuta_editor_goto_line
 ianjuta_editor_goto_position
@@ -535,7 +652,6 @@
 <SECTION>
 <FILE>ianjuta-bookmark</FILE>
 IANJUTA_BOOKMARK_ERROR
-<TITLE>IAnjutaBookmark</TITLE>
 IAnjutaBookmark
 IAnjutaBookmarkIface
 ianjuta_bookmark_error_quark
@@ -558,7 +674,6 @@
 IANJUTA_TYPE_BUILDABLE_COMMAND
 IAnjutaBuildableCommand
 IANJUTA_BUILDABLE_ERROR
-<TITLE>IAnjutaBuildable</TITLE>
 IAnjutaBuildable
 IAnjutaBuildableIface
 ianjuta_buildable_error_quark
@@ -581,29 +696,8 @@
 </SECTION>
 
 <SECTION>
-<FILE>ianjuta-cpu-debugger</FILE>
-IANJUTA_CPU_DEBUGGER_ERROR
-<TITLE>IAnjutaCpuDebugger</TITLE>
-IAnjutaCpuDebugger
-IAnjutaCpuDebuggerIface
-ianjuta_cpu_debugger_error_quark
-ianjuta_cpu_debugger_disassemble
-ianjuta_cpu_debugger_inspect_memory
-ianjuta_cpu_debugger_list_register
-ianjuta_cpu_debugger_update_register
-ianjuta_cpu_debugger_write_register
-<SUBSECTION Standard>
-IANJUTA_CPU_DEBUGGER
-IANJUTA_IS_CPU_DEBUGGER
-IANJUTA_TYPE_CPU_DEBUGGER
-ianjuta_cpu_debugger_get_type
-IANJUTA_CPU_DEBUGGER_GET_IFACE
-</SECTION>
-
-<SECTION>
 <FILE>ianjuta-debug-manager</FILE>
 IANJUTA_DEBUG_MANAGER_ERROR
-<TITLE>IAnjutaDebugManager</TITLE>
 IAnjutaDebugManager
 IAnjutaDebugManagerIface
 ianjuta_debug_manager_error_quark
@@ -617,35 +711,23 @@
 
 <SECTION>
 <FILE>ianjuta-debugger</FILE>
-IANJUTA_TYPE_DEBUGGER_BREAKPOINT_TYPE
 IANJUTA_TYPE_DEBUGGER_DATA
 IANJUTA_TYPE_DEBUGGER_ERROR
 IANJUTA_TYPE_DEBUGGER_OUTPUT_TYPE
 IANJUTA_TYPE_DEBUGGER_STATE
-IAnjutaDebuggerBreakpointType
 IAnjutaDebuggerData
 IAnjutaDebuggerError
 IAnjutaDebuggerOutputType
 IAnjutaDebuggerState
-IAnjutaDebuggerALine
-IAnjutaDebuggerBreakpoint
-IAnjutaDebuggerDisassembly
 IAnjutaDebuggerFrame
-IAnjutaDebuggerMemory
-IAnjutaDebuggerRegister
-IAnjutaDebuggerVariable
 IANJUTA_DEBUGGER_ERROR
 IAnjutaDebuggerCallback
 IAnjutaDebuggerGListCallback
 IAnjutaDebuggerGCharCallback
-IAnjutaDebuggerBreakpointCallback
 IAnjutaDebuggerOutputCallback
 IAnjutaDebuggerMemoryCallback
-IAnjutaDebuggerVariableCallback
-<TITLE>IAnjutaDebugger</TITLE>
 IAnjutaDebugger
 IAnjutaDebuggerIface
-ianjuta_debugger_data_get_type
 ianjuta_debugger_error_get_type
 ianjuta_debugger_output_type_get_type
 ianjuta_debugger_state_get_type
@@ -669,7 +751,6 @@
 ianjuta_debugger_info_thread
 ianjuta_debugger_info_udot
 ianjuta_debugger_info_variables
-ianjuta_debugger_initialize
 ianjuta_debugger_inspect
 ianjuta_debugger_interrupt
 ianjuta_debugger_list_argument
@@ -694,7 +775,7 @@
 IANJUTA_DEBUGGER
 IANJUTA_IS_DEBUGGER
 IANJUTA_TYPE_DEBUGGER
-ianjuta_debugger_breakpoint_type_get_type
+ianjuta_debugger_data_get_type
 IANJUTA_DEBUGGER_GET_IFACE
 </SECTION>
 
@@ -703,7 +784,6 @@
 IANJUTA_TYPE_DOCUMENT_MANAGER_ERROR
 IAnjutaDocumentManagerError
 IANJUTA_DOCUMENT_MANAGER_ERROR
-<TITLE>IAnjutaDocumentManager</TITLE>
 IAnjutaDocumentManager
 IAnjutaDocumentManagerIface
 ianjuta_document_manager_error_quark
@@ -712,7 +792,7 @@
 ianjuta_document_manager_add_document
 ianjuta_document_manager_find_document_with_path
 ianjuta_document_manager_get_current_document
-ianjuta_document_manager_get_documents
+ianjuta_document_manager_get_doc_widgets
 ianjuta_document_manager_get_full_filename
 ianjuta_document_manager_goto_file_line
 ianjuta_document_manager_goto_file_line_mark
@@ -729,7 +809,6 @@
 <SECTION>
 <FILE>ianjuta-editor-assist</FILE>
 IANJUTA_EDITOR_ASSIST_ERROR
-<TITLE>IAnjutaEditorAssist</TITLE>
 IAnjutaEditorAssist
 IAnjutaEditorAssistIface
 ianjuta_editor_assist_error_quark
@@ -749,7 +828,6 @@
 <SECTION>
 <FILE>ianjuta-editor-cell</FILE>
 IANJUTA_EDITOR_CELL_ERROR
-<TITLE>IAnjutaEditorCell</TITLE>
 IAnjutaEditorCell
 IAnjutaEditorCellIface
 ianjuta_editor_cell_error_quark
@@ -757,6 +835,7 @@
 ianjuta_editor_cell_get_char
 ianjuta_editor_cell_get_character
 ianjuta_editor_cell_get_length
+ianjuta_editor_cell_get_line
 <SUBSECTION Standard>
 IANJUTA_EDITOR_CELL
 IANJUTA_IS_EDITOR_CELL
@@ -768,7 +847,6 @@
 <SECTION>
 <FILE>ianjuta-editor-cell-style</FILE>
 IANJUTA_EDITOR_CELL_STYLE_ERROR
-<TITLE>IAnjutaEditorCellStyle</TITLE>
 IAnjutaEditorCellStyle
 IAnjutaEditorCellStyleIface
 ianjuta_editor_cell_style_error_quark
@@ -786,7 +864,6 @@
 <SECTION>
 <FILE>ianjuta-editor-comment</FILE>
 IANJUTA_EDITOR_COMMENT_ERROR
-<TITLE>IAnjutaEditorComment</TITLE>
 IAnjutaEditorComment
 IAnjutaEditorCommentIface
 ianjuta_editor_comment_error_quark
@@ -804,7 +881,6 @@
 <SECTION>
 <FILE>ianjuta-editor-convert</FILE>
 IANJUTA_EDITOR_CONVERT_ERROR
-<TITLE>IAnjutaEditorConvert</TITLE>
 IAnjutaEditorConvert
 IAnjutaEditorConvertIface
 ianjuta_editor_convert_error_quark
@@ -821,7 +897,6 @@
 <SECTION>
 <FILE>ianjuta-editor-factory</FILE>
 IANJUTA_EDITOR_FACTORY_ERROR
-<TITLE>IAnjutaEditorFactory</TITLE>
 IAnjutaEditorFactory
 IAnjutaEditorFactoryIface
 ianjuta_editor_factory_error_quark
@@ -837,7 +912,6 @@
 <SECTION>
 <FILE>ianjuta-editor-folds</FILE>
 IANJUTA_EDITOR_FOLDS_ERROR
-<TITLE>IAnjutaEditorFolds</TITLE>
 IAnjutaEditorFolds
 IAnjutaEditorFoldsIface
 ianjuta_editor_folds_error_quark
@@ -855,7 +929,6 @@
 <SECTION>
 <FILE>ianjuta-editor-goto</FILE>
 IANJUTA_EDITOR_GOTO_ERROR
-<TITLE>IAnjutaEditorGoto</TITLE>
 IAnjutaEditorGoto
 IAnjutaEditorGotoIface
 ianjuta_editor_goto_error_quark
@@ -873,12 +946,10 @@
 <SECTION>
 <FILE>ianjuta-editor-hover</FILE>
 IANJUTA_EDITOR_HOVER_ERROR
-<TITLE>IAnjutaEditorHover</TITLE>
 IAnjutaEditorHover
 IAnjutaEditorHoverIface
 ianjuta_editor_hover_error_quark
 ianjuta_editor_hover_display
-ianjuta_editor_hover_set_timeout
 <SUBSECTION Standard>
 IANJUTA_EDITOR_HOVER
 IANJUTA_IS_EDITOR_HOVER
@@ -890,7 +961,6 @@
 <SECTION>
 <FILE>ianjuta-editor-language</FILE>
 IANJUTA_EDITOR_LANGUAGE_ERROR
-<TITLE>IAnjutaEditorLanguage</TITLE>
 IAnjutaEditorLanguage
 IAnjutaEditorLanguageIface
 ianjuta_editor_language_error_quark
@@ -911,7 +981,6 @@
 IANJUTA_TYPE_EDITOR_LINE_MODE_TYPE
 IAnjutaEditorLineModeType
 IANJUTA_EDITOR_LINE_MODE_ERROR
-<TITLE>IAnjutaEditorLineMode</TITLE>
 IAnjutaEditorLineMode
 IAnjutaEditorLineModeIface
 ianjuta_editor_line_mode_error_quark
@@ -931,15 +1000,12 @@
 <SECTION>
 <FILE>ianjuta-editor-selection</FILE>
 IANJUTA_EDITOR_SELECTION_ERROR
-<TITLE>IAnjutaEditorSelection</TITLE>
 IAnjutaEditorSelection
 IAnjutaEditorSelectionIface
 ianjuta_editor_selection_error_quark
 ianjuta_editor_selection_get
 ianjuta_editor_selection_get_end
-ianjuta_editor_selection_get_end_iter
 ianjuta_editor_selection_get_start
-ianjuta_editor_selection_get_start_iter
 ianjuta_editor_selection_has_selection
 ianjuta_editor_selection_replace
 ianjuta_editor_selection_select_all
@@ -947,7 +1013,6 @@
 ianjuta_editor_selection_select_function
 ianjuta_editor_selection_select_to_brace
 ianjuta_editor_selection_set
-ianjuta_editor_selection_set_iter
 <SUBSECTION Standard>
 IANJUTA_EDITOR_SELECTION
 IANJUTA_IS_EDITOR_SELECTION
@@ -959,7 +1024,6 @@
 <SECTION>
 <FILE>ianjuta-editor-view</FILE>
 IANJUTA_EDITOR_VIEW_ERROR
-<TITLE>IAnjutaEditorView</TITLE>
 IAnjutaEditorView
 IAnjutaEditorViewIface
 ianjuta_editor_view_error_quark
@@ -977,7 +1041,6 @@
 <SECTION>
 <FILE>ianjuta-editor-zoom</FILE>
 IANJUTA_EDITOR_ZOOM_ERROR
-<TITLE>IAnjutaEditorZoom</TITLE>
 IAnjutaEditorZoom
 IAnjutaEditorZoomIface
 ianjuta_editor_zoom_error_quark
@@ -994,7 +1057,6 @@
 <SECTION>
 <FILE>ianjuta-file</FILE>
 IANJUTA_FILE_ERROR
-<TITLE>IAnjutaFile</TITLE>
 IAnjutaFile
 IAnjutaFileIface
 ianjuta_file_error_quark
@@ -1011,7 +1073,6 @@
 <SECTION>
 <FILE>ianjuta-file-loader</FILE>
 IANJUTA_FILE_LOADER_ERROR
-<TITLE>IAnjutaFileLoader</TITLE>
 IAnjutaFileLoader
 IAnjutaFileLoaderIface
 ianjuta_file_loader_error_quark
@@ -1028,7 +1089,6 @@
 <SECTION>
 <FILE>ianjuta-file-manager</FILE>
 IANJUTA_FILE_MANAGER_ERROR
-<TITLE>IAnjutaFileManager</TITLE>
 IAnjutaFileManager
 IAnjutaFileManagerIface
 ianjuta_file_manager_error_quark
@@ -1046,7 +1106,6 @@
 <SECTION>
 <FILE>ianjuta-file-savable</FILE>
 IANJUTA_FILE_SAVABLE_ERROR
-<TITLE>IAnjutaFileSavable</TITLE>
 IAnjutaFileSavable
 IAnjutaFileSavableIface
 ianjuta_file_savable_error_quark
@@ -1065,7 +1124,6 @@
 <SECTION>
 <FILE>ianjuta-help</FILE>
 IANJUTA_HELP_ERROR
-<TITLE>IAnjutaHelp</TITLE>
 IAnjutaHelp
 IAnjutaHelpIface
 ianjuta_help_error_quark
@@ -1083,7 +1141,6 @@
 IANJUTA_TYPE_INDICABLE_INDICATOR
 IAnjutaIndicableIndicator
 IANJUTA_INDICABLE_ERROR
-<TITLE>IAnjutaIndicable</TITLE>
 IAnjutaIndicable
 IAnjutaIndicableIface
 ianjuta_indicable_error_quark
@@ -1101,7 +1158,6 @@
 <SECTION>
 <FILE>ianjuta-iterable</FILE>
 IANJUTA_ITERABLE_ERROR
-<TITLE>IAnjutaIterable</TITLE>
 IAnjutaIterable
 IAnjutaIterableIface
 ianjuta_iterable_error_quark
@@ -1126,7 +1182,6 @@
 <SECTION>
 <FILE>ianjuta-iterable-tree</FILE>
 IANJUTA_ITERABLE_TREE_ERROR
-<TITLE>IAnjutaIterableTree</TITLE>
 IAnjutaIterableTree
 IAnjutaIterableTreeIface
 ianjuta_iterable_tree_error_quark
@@ -1146,7 +1201,6 @@
 <SECTION>
 <FILE>ianjuta-language-support</FILE>
 IANJUTA_LANGUAGE_SUPPORT_ERROR
-<TITLE>IAnjutaLanguageSupport</TITLE>
 IAnjutaLanguageSupport
 IAnjutaLanguageSupportIface
 ianjuta_language_support_error_quark
@@ -1163,7 +1217,6 @@
 <SECTION>
 <FILE>ianjuta-loader</FILE>
 IANJUTA_LOADER_ERROR
-<TITLE>IAnjutaLoader</TITLE>
 IAnjutaLoader
 IAnjutaLoaderIface
 ianjuta_loader_error_quark
@@ -1179,7 +1232,6 @@
 <SECTION>
 <FILE>ianjuta-macro</FILE>
 IANJUTA_MACRO_ERROR
-<TITLE>IAnjutaMacro</TITLE>
 IAnjutaMacro
 IAnjutaMacroIface
 ianjuta_macro_error_quark
@@ -1199,7 +1251,6 @@
 IAnjutaMarkableError
 IAnjutaMarkableMarker
 IANJUTA_MARKABLE_ERROR
-<TITLE>IAnjutaMarkable</TITLE>
 IAnjutaMarkable
 IAnjutaMarkableIface
 ianjuta_markable_marker_get_type
@@ -1223,7 +1274,6 @@
 IANJUTA_TYPE_MESSAGE_MANAGER_ERROR
 IAnjutaMessageManagerError
 IANJUTA_MESSAGE_MANAGER_ERROR
-<TITLE>IAnjutaMessageManager</TITLE>
 IAnjutaMessageManager
 IAnjutaMessageManagerIface
 ianjuta_message_manager_error_quark
@@ -1248,7 +1298,6 @@
 IANJUTA_TYPE_MESSAGE_VIEW_TYPE
 IAnjutaMessageViewType
 IANJUTA_MESSAGE_VIEW_ERROR
-<TITLE>IAnjutaMessageView</TITLE>
 IAnjutaMessageView
 IAnjutaMessageViewIface
 ianjuta_message_view_error_quark
@@ -1271,7 +1320,6 @@
 <SECTION>
 <FILE>ianjuta-preferences</FILE>
 IANJUTA_PREFERENCES_ERROR
-<TITLE>IAnjutaPreferences</TITLE>
 IAnjutaPreferences
 IAnjutaPreferencesIface
 ianjuta_preferences_error_quark
@@ -1288,7 +1336,6 @@
 <SECTION>
 <FILE>ianjuta-print</FILE>
 IANJUTA_PRINT_ERROR
-<TITLE>IAnjutaPrint</TITLE>
 IAnjutaPrint
 IAnjutaPrintIface
 ianjuta_print_error_quark
@@ -1303,6 +1350,21 @@
 </SECTION>
 
 <SECTION>
+<FILE>ianjuta-profile</FILE>
+IANJUTA_PROFILE_ERROR
+IAnjutaProfile
+IAnjutaProfileIface
+ianjuta_profile_error_quark
+ianjuta_profile_load
+<SUBSECTION Standard>
+IANJUTA_PROFILE
+IANJUTA_IS_PROFILE
+IANJUTA_TYPE_PROFILE
+ianjuta_profile_get_type
+IANJUTA_PROFILE_GET_IFACE
+</SECTION>
+
+<SECTION>
 <FILE>ianjuta-project-manager</FILE>
 IANJUTA_TYPE_PROJECT_MANAGER_CAPABILITIES
 IANJUTA_TYPE_PROJECT_MANAGER_ELEMENT_TYPE
@@ -1311,7 +1373,6 @@
 IAnjutaProjectManagerElementType
 IAnjutaProjectManagerTargetType
 IANJUTA_PROJECT_MANAGER_ERROR
-<TITLE>IAnjutaProjectManager</TITLE>
 IAnjutaProjectManager
 IAnjutaProjectManagerIface
 ianjuta_project_manager_element_type_get_type
@@ -1320,7 +1381,7 @@
 ianjuta_project_manager_get_type
 ianjuta_project_manager_add_group
 ianjuta_project_manager_add_source
-ianjuta_project_manager_add_source_multi
+ianjuta_project_manager_add_sources
 ianjuta_project_manager_add_target
 ianjuta_project_manager_get_capabilities
 ianjuta_project_manager_get_children
@@ -1342,7 +1403,6 @@
 <SECTION>
 <FILE>ianjuta-stream</FILE>
 IANJUTA_STREAM_ERROR
-<TITLE>IAnjutaStream</TITLE>
 IAnjutaStream
 IAnjutaStreamIface
 ianjuta_stream_error_quark
@@ -1358,7 +1418,6 @@
 <SECTION>
 <FILE>ianjuta-stream-loader</FILE>
 IANJUTA_STREAM_LOADER_ERROR
-<TITLE>IAnjutaStreamLoader</TITLE>
 IAnjutaStreamLoader
 IAnjutaStreamLoaderIface
 ianjuta_stream_loader_error_quark
@@ -1375,7 +1434,6 @@
 <SECTION>
 <FILE>ianjuta-stream-savable</FILE>
 IANJUTA_STREAM_SAVABLE_ERROR
-<TITLE>IAnjutaStreamSavable</TITLE>
 IAnjutaStreamSavable
 IAnjutaStreamSavableIface
 ianjuta_stream_savable_error_quark
@@ -1395,7 +1453,6 @@
 IAnjutaSymbolField
 IAnjutaSymbolType
 IANJUTA_SYMBOL_ERROR
-<TITLE>IAnjutaSymbol</TITLE>
 IAnjutaSymbol
 IAnjutaSymbolIface
 ianjuta_symbol_type_get_type
@@ -1426,7 +1483,6 @@
 <SECTION>
 <FILE>ianjuta-symbol-manager</FILE>
 IANJUTA_SYMBOL_MANAGER_ERROR
-<TITLE>IAnjutaSymbolManager</TITLE>
 IAnjutaSymbolManager
 IAnjutaSymbolManagerIface
 ianjuta_symbol_manager_error_quark
@@ -1445,7 +1501,6 @@
 <SECTION>
 <FILE>ianjuta-terminal</FILE>
 IANJUTA_TERMINAL_ERROR
-<TITLE>IAnjutaTerminal</TITLE>
 IAnjutaTerminal
 IAnjutaTerminalIface
 ianjuta_terminal_error_quark
@@ -1461,7 +1516,6 @@
 <SECTION>
 <FILE>ianjuta-todo</FILE>
 IANJUTA_TODO_ERROR
-<TITLE>IAnjutaTodo</TITLE>
 IAnjutaTodo
 IAnjutaTodoIface
 ianjuta_todo_error_quark
@@ -1475,30 +1529,8 @@
 </SECTION>
 
 <SECTION>
-<FILE>ianjuta-variable-debugger</FILE>
-IANJUTA_VARIABLE_DEBUGGER_ERROR
-<TITLE>IAnjutaVariableDebugger</TITLE>
-IAnjutaVariableDebugger
-IAnjutaVariableDebuggerIface
-ianjuta_variable_debugger_error_quark
-ianjuta_variable_debugger_assign
-ianjuta_variable_debugger_create
-ianjuta_variable_debugger_delete_var
-ianjuta_variable_debugger_evaluate
-ianjuta_variable_debugger_list_children
-ianjuta_variable_debugger_update
-<SUBSECTION Standard>
-IANJUTA_VARIABLE_DEBUGGER
-IANJUTA_IS_VARIABLE_DEBUGGER
-IANJUTA_TYPE_VARIABLE_DEBUGGER
-ianjuta_variable_debugger_get_type
-IANJUTA_VARIABLE_DEBUGGER_GET_IFACE
-</SECTION>
-
-<SECTION>
 <FILE>ianjuta-vcs</FILE>
 IANJUTA_VCS_ERROR
-<TITLE>IAnjutaVcs</TITLE>
 IAnjutaVcs
 IAnjutaVcsIface
 ianjuta_vcs_error_quark
@@ -1517,7 +1549,6 @@
 <SECTION>
 <FILE>ianjuta-wizard</FILE>
 IANJUTA_WIZARD_ERROR
-<TITLE>IAnjutaWizard</TITLE>
 IAnjutaWizard
 IAnjutaWizardIface
 ianjuta_wizard_error_quark
@@ -1531,45 +1562,8 @@
 </SECTION>
 
 <SECTION>
-<FILE>ianjuta-plugin-factory</FILE>
-IANJUTA_TYPE_PLUGIN_FACTORY_ERROR
-IAnjutaPluginFactoryError
-IANJUTA_PLUGIN_FACTORY_ERROR
-<TITLE>IAnjutaPluginFactory</TITLE>
-IAnjutaPluginFactory
-IAnjutaPluginFactoryIface
-ianjuta_plugin_factory_error_quark
-ianjuta_plugin_factory_get_type
-ianjuta_plugin_factory_new_plugin
-<SUBSECTION Standard>
-IANJUTA_PLUGIN_FACTORY
-IANJUTA_IS_PLUGIN_FACTORY
-IANJUTA_TYPE_PLUGIN_FACTORY
-ianjuta_plugin_factory_error_get_type
-IANJUTA_PLUGIN_FACTORY_GET_IFACE
-</SECTION>
-
-<SECTION>
-<FILE>ianjuta-editor-search</FILE>
-IANJUTA_EDITOR_SEARCH_ERROR
-<TITLE>IAnjutaEditorSearch</TITLE>
-IAnjutaEditorSearch
-IAnjutaEditorSearchIface
-ianjuta_editor_search_error_quark
-ianjuta_editor_search_backward
-ianjuta_editor_search_forward
-<SUBSECTION Standard>
-IANJUTA_EDITOR_SEARCH
-IANJUTA_IS_EDITOR_SEARCH
-IANJUTA_TYPE_EDITOR_SEARCH
-ianjuta_editor_search_get_type
-IANJUTA_EDITOR_SEARCH_GET_IFACE
-</SECTION>
-
-<SECTION>
 <FILE>ianjuta-document</FILE>
 IANJUTA_DOCUMENT_ERROR
-<TITLE>IAnjutaDocument</TITLE>
 IAnjutaDocument
 IAnjutaDocumentIface
 ianjuta_document_error_quark
@@ -1594,9 +1588,47 @@
 </SECTION>
 
 <SECTION>
+<FILE>ianjuta-debugger-instruction</FILE>
+IAnjutaDebuggerInstructionALine
+IAnjutaDebuggerInstructionDisassembly
+IANJUTA_DEBUGGER_INSTRUCTION_ERROR
+IAnjutaDebuggerInstruction
+IAnjutaDebuggerInstructionIface
+ianjuta_debugger_instruction_error_quark
+ianjuta_debugger_instruction_disassemble
+ianjuta_debugger_instruction_run_to_address
+ianjuta_debugger_instruction_step_in
+ianjuta_debugger_instruction_step_over
+<SUBSECTION Standard>
+IANJUTA_DEBUGGER_INSTRUCTION
+IANJUTA_IS_DEBUGGER_INSTRUCTION
+IANJUTA_TYPE_DEBUGGER_INSTRUCTION
+ianjuta_debugger_instruction_get_type
+IANJUTA_DEBUGGER_INSTRUCTION_GET_IFACE
+</SECTION>
+
+<SECTION>
+<FILE>ianjuta-debugger-cpu</FILE>
+IANJUTA_DEBUGGER_CPU_ERROR
+IAnjutaDebuggerCpu
+IAnjutaDebuggerCpuIface
+ianjuta_debugger_cpu_error_quark
+ianjuta_debugger_cpu_disassemble
+ianjuta_debugger_cpu_inspect_memory
+ianjuta_debugger_cpu_list_register
+ianjuta_debugger_cpu_update_register
+ianjuta_debugger_cpu_write_register
+<SUBSECTION Standard>
+IANJUTA_DEBUGGER_CPU
+IANJUTA_IS_DEBUGGER_CPU
+IANJUTA_TYPE_DEBUGGER_CPU
+ianjuta_debugger_cpu_get_type
+IANJUTA_DEBUGGER_CPU_GET_IFACE
+</SECTION>
+
+<SECTION>
 <FILE>ianjuta-breakpoint-debugger</FILE>
 IANJUTA_BREAKPOINT_DEBUGGER_ERROR
-<TITLE>IAnjutaBreakpointDebugger</TITLE>
 IAnjutaBreakpointDebugger
 IAnjutaBreakpointDebuggerIface
 ianjuta_breakpoint_debugger_error_quark
@@ -1616,26 +1648,9 @@
 </SECTION>
 
 <SECTION>
-<FILE>ianjuta-plugin-loader</FILE>
-IANJUTA_PLUGIN_LOADER_ERROR
-<TITLE>IAnjutaPluginLoader</TITLE>
-IAnjutaPluginLoader
-IAnjutaPluginLoaderIface
-ianjuta_plugin_loader_error_quark
-ianjuta_plugin_loader_glue_plugin_get_type
-<SUBSECTION Standard>
-IANJUTA_PLUGIN_LOADER
-IANJUTA_IS_PLUGIN_LOADER
-IANJUTA_TYPE_PLUGIN_LOADER
-ianjuta_plugin_loader_get_type
-IANJUTA_PLUGIN_LOADER_GET_IFACE
-</SECTION>
-
-<SECTION>
 <FILE>ianjuta-language</FILE>
 IANJUTA_LANGUAGE_ERROR
 IAnjutaLanguageId
-<TITLE>IAnjutaLanguage</TITLE>
 IAnjutaLanguage
 IAnjutaLanguageIface
 ianjuta_language_error_quark
@@ -1654,63 +1669,177 @@
 </SECTION>
 
 <SECTION>
-<FILE>anjuta-plugin-manager</FILE>
-AnjutaPluginManagerPriv
-<TITLE>AnjutaPluginManager</TITLE>
-AnjutaPluginManager
-anjuta_plugin_manager_new
-anjuta_plugin_manager_push_profile
-anjuta_plugin_manager_pop_profile
-anjuta_plugin_manager_freeze
-anjuta_plugin_manager_thaw
-anjuta_plugin_manager_get_plugin
-anjuta_plugin_manager_get_plugin_by_id
-anjuta_plugin_manager_unload_plugin
-anjuta_plugin_manager_unload_plugin_by_id
-anjuta_plugin_manager_get_active_plugins
-anjuta_plugin_manager_get_dialog
-anjuta_plugin_manager_query
-anjuta_plugin_manager_select
-anjuta_plugin_manager_select_and_activate
-anjuta_plugin_manager_unload_all_plugins
-anjuta_plugin_manager_get_interface
+<FILE>ianjuta-plugin-loader</FILE>
+IANJUTA_PLUGIN_LOADER_ERROR
+IAnjutaPluginLoader
+IAnjutaPluginLoaderIface
+ianjuta_plugin_loader_error_quark
+ianjuta_plugin_loader_new_module
 <SUBSECTION Standard>
-ANJUTA_PLUGIN_MANAGER
-ANJUTA_IS_PLUGIN_MANAGER
-ANJUTA_TYPE_PLUGIN_MANAGER
-anjuta_plugin_manager_get_type
-ANJUTA_PLUGIN_MANAGER_CLASS
-ANJUTA_IS_PLUGIN_MANAGER_CLASS
-ANJUTA_PLUGIN_MANAGER_GET_CLASS
+IANJUTA_PLUGIN_LOADER
+IANJUTA_IS_PLUGIN_LOADER
+IANJUTA_TYPE_PLUGIN_LOADER
+ianjuta_plugin_loader_get_type
+IANJUTA_PLUGIN_LOADER_GET_IFACE
 </SECTION>
 
 <SECTION>
-<FILE>anjuta-profile</FILE>
-AnjutaProfilePriv
-<TITLE>AnjutaProfile</TITLE>
-AnjutaProfile
-anjuta_profile_new
-anjuta_profile_new_from_xml
-anjuta_profile_add_plugin
-anjuta_profile_remove_plugin
-anjuta_profile_has_plugin
-anjuta_profile_to_xml
-anjuta_profile_get_plugins
-anjuta_profile_difference_positive
-anjuta_profile_difference_negative
+<FILE>ianjuta-editor-search</FILE>
+IANJUTA_EDITOR_SEARCH_ERROR
+IAnjutaEditorSearch
+IAnjutaEditorSearchIface
+ianjuta_editor_search_error_quark
+ianjuta_editor_search_backward
+ianjuta_editor_search_forward
 <SUBSECTION Standard>
-ANJUTA_PROFILE
-ANJUTA_IS_PROFILE
-ANJUTA_TYPE_PROFILE
-anjuta_profile_get_type
-ANJUTA_PROFILE_CLASS
-ANJUTA_IS_PROFILE_CLASS
-ANJUTA_PROFILE_GET_CLASS
+IANJUTA_EDITOR_SEARCH
+IANJUTA_IS_EDITOR_SEARCH
+IANJUTA_TYPE_EDITOR_SEARCH
+ianjuta_editor_search_get_type
+IANJUTA_EDITOR_SEARCH_GET_IFACE
+</SECTION>
+
+<SECTION>
+<FILE>ianjuta-plugin-factory</FILE>
+IANJUTA_TYPE_PLUGIN_FACTORY_ERROR
+IAnjutaPluginFactoryError
+IANJUTA_PLUGIN_FACTORY_ERROR
+IAnjutaPluginFactory
+IAnjutaPluginFactoryIface
+ianjuta_plugin_factory_error_quark
+ianjuta_plugin_factory_get_type
+ianjuta_plugin_factory_new_plugin
+<SUBSECTION Standard>
+IANJUTA_PLUGIN_FACTORY
+IANJUTA_IS_PLUGIN_FACTORY
+IANJUTA_TYPE_PLUGIN_FACTORY
+ianjuta_plugin_factory_error_get_type
+IANJUTA_PLUGIN_FACTORY_GET_IFACE
+</SECTION>
+
+<SECTION>
+<FILE>ianjuta-debugger-memory</FILE>
+IAnjutaDebuggerMemoryBlock
+IANJUTA_DEBUGGER_MEMORY_ERROR
+IAnjutaDebuggerMemory
+IAnjutaDebuggerMemoryIface
+ianjuta_debugger_memory_error_quark
+ianjuta_debugger_memory_inspect
+<SUBSECTION Standard>
+IANJUTA_DEBUGGER_MEMORY
+IANJUTA_IS_DEBUGGER_MEMORY
+IANJUTA_TYPE_DEBUGGER_MEMORY
+ianjuta_debugger_memory_get_type
+IANJUTA_DEBUGGER_MEMORY_GET_IFACE
+</SECTION>
+
+<SECTION>
+<FILE>ianjuta-editor-autocomplete</FILE>
+IANJUTA_EDITOR_AUTOCOMPLETE_ERROR
+IAnjutaEditorAutocomplete
+IAnjutaEditorAutocompleteIface
+ianjuta_editor_autocomplete_error_quark
+ianjuta_editor_autocomplete_activate
+<SUBSECTION Standard>
+IANJUTA_EDITOR_AUTOCOMPLETE
+IANJUTA_IS_EDITOR_AUTOCOMPLETE
+IANJUTA_TYPE_EDITOR_AUTOCOMPLETE
+ianjuta_editor_autocomplete_get_type
+IANJUTA_EDITOR_AUTOCOMPLETE_GET_IFACE
+</SECTION>
+
+<SECTION>
+<FILE>ianjuta-debugger-variable</FILE>
+IAnjutaDebuggerVariableObject
+IANJUTA_DEBUGGER_VARIABLE_ERROR
+IAnjutaDebuggerVariable
+IAnjutaDebuggerVariableIface
+ianjuta_debugger_variable_error_quark
+ianjuta_debugger_variable_assign
+ianjuta_debugger_variable_create
+ianjuta_debugger_variable_destroy
+ianjuta_debugger_variable_evaluate
+ianjuta_debugger_variable_list_children
+ianjuta_debugger_variable_update
+<SUBSECTION Standard>
+IANJUTA_DEBUGGER_VARIABLE
+IANJUTA_IS_DEBUGGER_VARIABLE
+IANJUTA_TYPE_DEBUGGER_VARIABLE
+ianjuta_debugger_variable_get_type
+IANJUTA_DEBUGGER_VARIABLE_GET_IFACE
+</SECTION>
+
+<SECTION>
+<FILE>ianjuta-debugger-breakpoint</FILE>
+IANJUTA_TYPE_DEBUGGER_BREAKPOINT_METHOD
+IANJUTA_TYPE_DEBUGGER_BREAKPOINT_TYPE
+IAnjutaDebuggerBreakpointMethod
+IAnjutaDebuggerBreakpointType
+IAnjutaDebuggerBreakpointItem
+IANJUTA_DEBUGGER_BREAKPOINT_ERROR
+IAnjutaDebuggerBreakpoint
+IAnjutaDebuggerBreakpointIface
+ianjuta_debugger_breakpoint_type_get_type
+ianjuta_debugger_breakpoint_error_quark
+ianjuta_debugger_breakpoint_get_type
+ianjuta_debugger_breakpoint_clear
+ianjuta_debugger_breakpoint_condition
+ianjuta_debugger_breakpoint_enable
+ianjuta_debugger_breakpoint_ignore
+ianjuta_debugger_breakpoint_implement
+ianjuta_debugger_breakpoint_list
+ianjuta_debugger_breakpoint_set_at_address
+ianjuta_debugger_breakpoint_set_at_function
+ianjuta_debugger_breakpoint_set_at_line
+<SUBSECTION Standard>
+IANJUTA_DEBUGGER_BREAKPOINT
+IANJUTA_IS_DEBUGGER_BREAKPOINT
+IANJUTA_TYPE_DEBUGGER_BREAKPOINT
+ianjuta_debugger_breakpoint_method_get_type
+IANJUTA_DEBUGGER_BREAKPOINT_GET_IFACE
+</SECTION>
+
+<SECTION>
+<FILE>ianjutai-debugger-variable</FILE>
+IAnjutaiDebuggerVariableObject
+IANJUTAI_DEBUGGER_VARIABLE_ERROR
+IAnjutaiDebuggerVariable
+IAnjutaiDebuggerVariableIface
+ianjutai_debugger_variable_error_quark
+ianjutai_debugger_variable_assign
+ianjutai_debugger_variable_create
+ianjutai_debugger_variable_destroy
+ianjutai_debugger_variable_evaluate
+ianjutai_debugger_variable_list_children
+ianjutai_debugger_variable_update
+<SUBSECTION Standard>
+IANJUTAI_DEBUGGER_VARIABLE
+IANJUTAI_IS_DEBUGGER_VARIABLE
+IANJUTAI_TYPE_DEBUGGER_VARIABLE
+ianjutai_debugger_variable_get_type
+IANJUTAI_DEBUGGER_VARIABLE_GET_IFACE
+</SECTION>
+
+<SECTION>
+<FILE>ianjuta-debugger-register</FILE>
+IAnjutaDebuggerRegisterData
+IANJUTA_DEBUGGER_REGISTER_ERROR
+IAnjutaDebuggerRegister
+IAnjutaDebuggerRegisterIface
+ianjuta_debugger_register_error_quark
+ianjuta_debugger_register_list
+ianjuta_debugger_register_update
+ianjuta_debugger_register_write_register
+<SUBSECTION Standard>
+IANJUTA_DEBUGGER_REGISTER
+IANJUTA_IS_DEBUGGER_REGISTER
+IANJUTA_TYPE_DEBUGGER_REGISTER
+ianjuta_debugger_register_get_type
+IANJUTA_DEBUGGER_REGISTER_GET_IFACE
 </SECTION>
 
 <SECTION>
 <FILE>anjuta-plugin-description</FILE>
-<TITLE>AnjutaPluginDescription</TITLE>
 AnjutaPluginDescription
 AnjutaPluginDescriptionSectionFunc
 AnjutaPluginDescriptionLineFunc
@@ -1731,13 +1860,15 @@
 
 <SECTION>
 <FILE>anjuta-debug</FILE>
-<TITLE>Debugging utilities</TITLE>
 DEBUG_PRINT
 </SECTION>
 
 <SECTION>
+<FILE>libanjuta</FILE>
+</SECTION>
+
+<SECTION>
 <FILE>resources</FILE>
-<TITLE>Program resources</TITLE>
 anjuta_res_lookup_widget
 anjuta_res_get_image
 anjuta_res_get_image_sized
@@ -1756,27 +1887,7 @@
 </SECTION>
 
 <SECTION>
-<FILE>anjuta-marshal</FILE>
-<TITLE>Marshallers</TITLE>
-anjuta_cclosure_marshal_VOID__VOID
-anjuta_cclosure_marshal_VOID__BOOLEAN
-anjuta_cclosure_marshal_VOID__INT_STRING
-anjuta_cclosure_marshal_VOID__INT_OBJECT
-anjuta_cclosure_marshal_VOID__INT_INT_ULONG
-anjuta_cclosure_marshal_VOID__STRING_POINTER
-anjuta_cclosure_marshal_VOID__STRING
-anjuta_cclosure_marshal_VOID__STRING_INT
-anjuta_cclosure_marshal_VOID__STRING_INT_STRING
-anjuta_cclosure_marshal_VOID__STRING_BOXED
-anjuta_cclosure_marshal_VOID__POINTER
-anjuta_cclosure_marshal_VOID__OBJECT
-anjuta_cclosure_marshal_VOID__BOXED_ENUM
-anjuta_cclosure_marshal_VOID__POINTER_OBJECT
-</SECTION>
-
-<SECTION>
 <FILE>anjuta-encodings</FILE>
-<TITLE>Encodings</TITLE>
 AnjutaEncoding
 anjuta_encoding_get_from_charset
 anjuta_encoding_get_from_index
@@ -1791,7 +1902,6 @@
 
 <SECTION>
 <FILE>anjuta-utils</FILE>
-<TITLE>Utilities</TITLE>
 anjuta_util_copy_file
 anjuta_util_diff
 anjuta_util_color_from_string
@@ -1824,6 +1934,7 @@
 anjuta_util_execute_shell
 anjuta_util_escape_quotes
 anjuta_util_path_has_extension
+anjuta_util_get_real_path
 anjuta_util_get_uri_mime_type
 ANJUTA_TYPE_BEGIN
 ANJUTA_TYPE_END
@@ -1832,8 +1943,25 @@
 </SECTION>
 
 <SECTION>
+<FILE>anjuta-marshal</FILE>
+anjuta_cclosure_marshal_VOID__VOID
+anjuta_cclosure_marshal_VOID__BOOLEAN
+anjuta_cclosure_marshal_VOID__INT_STRING
+anjuta_cclosure_marshal_VOID__INT_OBJECT
+anjuta_cclosure_marshal_VOID__INT_INT_ULONG
+anjuta_cclosure_marshal_VOID__STRING_POINTER
+anjuta_cclosure_marshal_VOID__STRING
+anjuta_cclosure_marshal_VOID__STRING_INT
+anjuta_cclosure_marshal_VOID__STRING_INT_STRING
+anjuta_cclosure_marshal_VOID__STRING_BOXED
+anjuta_cclosure_marshal_VOID__POINTER
+anjuta_cclosure_marshal_VOID__OBJECT
+anjuta_cclosure_marshal_VOID__BOXED_ENUM
+anjuta_cclosure_marshal_VOID__POINTER_OBJECT
+</SECTION>
+
+<SECTION>
 <FILE>anjuta-enum-types</FILE>
-<TITLE>Enumaretions</TITLE>
 anjuta_shell_error_get_type
 ANJUTA_TYPE_SHELL_ERROR
 anjuta_shell_placement_get_type
@@ -1856,25 +1984,63 @@
 ANJUTA_TYPE_SESSION_PHASE
 anjuta_serializer_mode_get_type
 ANJUTA_TYPE_SERIALIZER_MODE
+anjuta_vcs_status_get_type
+ANJUTA_TYPE_VCS_STATUS
 </SECTION>
 
 <SECTION>
-<FILE>anjuta-utils-priv</FILE>
-<TITLE>Private utilities</TITLE>
-forkpty
+<FILE>stamp-anjuta-enum-types</FILE>
+</SECTION>
+
+<SECTION>
+<FILE>anjuta-boxed</FILE>
+IAnjutaDebuggerBreakpoint
+IANJUTA_TYPE_DEBUGGER_BREAKPOINT_TYPE
+ianjuta_debugger_breakpoint_type_get_type
+IANJUTA_TYPE_DEBUGGER_BREAKPOINT
+ianjuta_debugger_breakpoint_get_type
+ianjuta_debugger_breakpoint_new
+ianjuta_debugger_breakpoint_free
+ianjuta_debugger_breakpoint_copy
+ianjuta_debugger_breakpoint_is_equal
 </SECTION>
 
 <SECTION>
 <FILE>anjuta-error</FILE>
-<TITLE>AnjutaError</TITLE>
 G_TYPE_ERROR
 NEED_G_ERROR_GET_TYPE
 g_error_get_type
 </SECTION>
 
 <SECTION>
+<FILE>anjuta-utils-priv</FILE>
+forkpty
+</SECTION>
+
+<SECTION>
+<FILE>anjuta-widgets</FILE>
+</SECTION>
+
+<SECTION>
+<FILE>anjuta-async-command</FILE>
+ANJUTA_TYPE_ASYNC_COMMAND
+ANJUTA_ASYNC_COMMAND
+ANJUTA_ASYNC_COMMAND_CLASS
+IS_ANJUTA_ASYNC_COMMAND
+IS_ANJUTA_ASYNC_COMMAND_CLASS
+ANJUTA_ASYNC_COMMAND_GET_CLASS
+AnjutaAsyncCommandPriv
+<TITLE>AnjutaAsyncCommand</TITLE>
+AnjutaAsyncCommand
+anjuta_async_command_get_type
+anjuta_async_command_set_error_message
+anjuta_async_command_get_error_message
+anjuta_async_command_lock
+anjuta_async_command_unlock
+</SECTION>
+
+<SECTION>
 <FILE>libanjuta-iface-marshallers</FILE>
-<TITLE>Interface marshallers</TITLE>
 libanjuta_iface_cclosure_marshal_VOID__BOOLEAN
 libanjuta_iface_cclosure_marshal_VOID__BOOLEAN_INT
 libanjuta_iface_cclosure_marshal_VOID__BOXED
@@ -1882,10 +2048,17 @@
 libanjuta_iface_cclosure_marshal_VOID__INT
 libanjuta_iface_cclosure_marshal_VOID__INT_BOOLEAN_INT_INT_STRING
 libanjuta_iface_cclosure_marshal_VOID__INT_CHAR
-libanjuta_iface_cclosure_marshal_VOID__INT_INT_UINT_STRING_UINT
+libanjuta_iface_cclosure_marshal_VOID__INT_INT_ULONG_STRING_UINT
+libanjuta_iface_cclosure_marshal_VOID__OBJECT
 libanjuta_iface_cclosure_marshal_VOID__POINTER
 libanjuta_iface_cclosure_marshal_VOID__STRING
 libanjuta_iface_cclosure_marshal_VOID__STRING_STRING
 libanjuta_iface_cclosure_marshal_VOID__UINT_INT
+libanjuta_iface_cclosure_marshal_VOID__ULONG_STRING_UINT
 libanjuta_iface_cclosure_marshal_VOID__VOID
 </SECTION>
+
+<SECTION>
+<FILE>libanjuta-interfaces</FILE>
+</SECTION>
+

Modified: trunk/manuals/reference/libanjuta/libanjuta.types
==============================================================================
--- trunk/manuals/reference/libanjuta/libanjuta.types	(original)
+++ trunk/manuals/reference/libanjuta/libanjuta.types	Fri Jan 18 20:40:36 2008
@@ -17,8 +17,12 @@
 anjuta_session_get_type
 ianjuta_bookmark_get_type
 ianjuta_buildable_get_type
-ianjuta_cpu_debugger_get_type
 ianjuta_debugger_get_type
+ianjuta_debugger_breakpoint_get_type
+ianjuta_debugger_variable_get_type
+ianjuta_debugger_register_get_type
+ianjuta_debugger_memory_get_type
+ianjuta_debugger_instruction_get_type
 ianjuta_debug_manager_get_type
 ianjuta_document_manager_get_type
 ianjuta_editor_assist_get_type
@@ -60,6 +64,5 @@
 ianjuta_symbol_manager_get_type
 ianjuta_terminal_get_type
 ianjuta_todo_get_type
-ianjuta_debugger_variable_get_type
 ianjuta_vcs_get_type
 ianjuta_wizard_get_type

Modified: trunk/plugins/debug-manager/breakpoints.c
==============================================================================
--- trunk/plugins/debug-manager/breakpoints.c	(original)
+++ trunk/plugins/debug-manager/breakpoints.c	Fri Jan 18 20:40:36 2008
@@ -398,7 +398,7 @@
 	const gchar *filename;
 	const gchar *format;
 
-	adr = g_strdup_printf ("0x%x", bi->bp.address);
+	adr = g_strdup_printf ("0x%lx", bi->bp.address);
 	if (bi->bp.file != NULL)
 	{
 		filename = strrchr(bi->bp.file, G_DIR_SEPARATOR);
@@ -1472,7 +1472,7 @@
 	else if (bi->bp.address != 0)
 	{
 		// address
-		location = g_strdup_printf ("*%x", bi->bp.address);
+		location = g_strdup_printf ("*%lx", bi->bp.address);
 	}
 
 	if (GTK_WIDGET_VISIBLE(location_entry))
@@ -1832,7 +1832,7 @@
 	
 			gtk_tree_model_get (model, &iter, DATA_COLUMN, &bi, -1);
 			action = gtk_action_group_get_action (bd->debugger_group, "ActionDmaEnableDisableBreakpoint");
-			g_return_if_fail (action != NULL);
+			g_return_val_if_fail (action != NULL, FALSE);
 			if (bi->bp.enable)
 			{
 				label =	N_("Disable Breakpoint");

Modified: trunk/plugins/debug-manager/command.c
==============================================================================
--- trunk/plugins/debug-manager/command.c	(original)
+++ trunk/plugins/debug-manager/command.c	Fri Jan 18 20:40:36 2008
@@ -31,7 +31,9 @@
 /*#define DEBUG*/
 #include <libanjuta/anjuta-debug.h>
 #include <libanjuta/interfaces/ianjuta-debugger-breakpoint.h>
-#include <libanjuta/interfaces/ianjuta-cpu-debugger.h>
+#include <libanjuta/interfaces/ianjuta-debugger-register.h>
+#include <libanjuta/interfaces/ianjuta-debugger-memory.h>
+#include <libanjuta/interfaces/ianjuta-debugger-instruction.h>
 #include <libanjuta/interfaces/ianjuta-debugger-variable.h>
 
 #include <stdarg.h>
@@ -298,7 +300,7 @@
 		struct {
 			gchar *file;
 			guint line;
-			guint address;
+			gulong address;
 			gchar *function;
 		} pos;
 		struct {
@@ -331,7 +333,7 @@
 			guint frame;
 		} frame;
 		struct {
-			guint address;
+			gulong address;
 			guint length;
 		} mem;
 		struct {
@@ -350,7 +352,7 @@
 {
 	DmaQueueCommand* cmd;
 	DmaDebuggerCommandType type = cmd_type & COMMAND_MASK;
-	IAnjutaDebuggerRegister* reg;
+	IAnjutaDebuggerRegisterData* reg;
 	va_list args;
 	GList *list;
 	
@@ -449,7 +451,7 @@
 		cmd->user_data = va_arg (args, gpointer);
 		break;
 	case BREAK_ADDRESS_COMMAND:
-		cmd->data.pos.address = va_arg (args, guint);
+		cmd->data.pos.address = va_arg (args, gulong);
 		cmd->callback = va_arg (args, IAnjutaDebuggerCallback);
 		cmd->user_data = va_arg (args, gpointer);
 		break;
@@ -542,19 +544,19 @@
 		cmd->user_data = va_arg (args, gpointer);
 		break;
 	case WRITE_REGISTER_COMMAND:
-		reg = va_arg (args, IAnjutaDebuggerRegister *);
+		reg = va_arg (args, IAnjutaDebuggerRegisterData *);
 		cmd->data.watch.id = reg->num;
 	    cmd->data.watch.name = g_strdup (reg->name);
 	    cmd->data.watch.value = g_strdup (reg->value);
 		break;
 	case INSPECT_MEMORY_COMMAND:
-		cmd->data.mem.address = va_arg (args, guint);
+		cmd->data.mem.address = va_arg (args, gulong);
 	    cmd->data.mem.length = va_arg (args, guint);
 		cmd->callback = va_arg (args, IAnjutaDebuggerCallback);
 		cmd->user_data = va_arg (args, gpointer);
 		break;
 	case DISASSEMBLE_COMMAND:
-		cmd->data.mem.address = va_arg (args, guint);
+		cmd->data.mem.address = va_arg (args, gulong);
 	    cmd->data.mem.length = va_arg (args, guint);
 		cmd->callback = va_arg (args, IAnjutaDebuggerCallback);
 		cmd->user_data = va_arg (args, gpointer);
@@ -690,7 +692,7 @@
 }
 
 gboolean
-dma_queue_run_to_address (DmaDebuggerQueue *self, guint address)
+dma_queue_run_to_address (DmaDebuggerQueue *self, gulong address)
 {
 	return dma_debugger_queue_append (self, dma_command_new (DMA_RUN_TO_ADDRESS_COMMAND, address));
 }
@@ -846,7 +848,7 @@
 }
 
 gboolean
-dma_queue_add_breakpoint_at_address (DmaDebuggerQueue *self, guint address, IAnjutaDebuggerCallback callback, gpointer user_data)
+dma_queue_add_breakpoint_at_address (DmaDebuggerQueue *self, gulong address, IAnjutaDebuggerCallback callback, gpointer user_data)
 {
 	return dma_debugger_queue_append (self, dma_command_new (DMA_BREAK_ADDRESS_COMMAND, address, callback, user_data));
 }
@@ -894,19 +896,19 @@
 }
 
 gboolean
-dma_queue_write_register (DmaDebuggerQueue *self, IAnjutaDebuggerRegister *value)
+dma_queue_write_register (DmaDebuggerQueue *self, IAnjutaDebuggerRegisterData *value)
 {
 	return dma_debugger_queue_append (self, dma_command_new (DMA_WRITE_REGISTER_COMMAND, value));
 }
 
 gboolean
-dma_queue_inspect_memory (DmaDebuggerQueue *self, guint address, guint length, IAnjutaDebuggerCallback callback , gpointer user_data)
+dma_queue_inspect_memory (DmaDebuggerQueue *self, gulong address, guint length, IAnjutaDebuggerCallback callback , gpointer user_data)
 {
 	return dma_debugger_queue_append (self, dma_command_new (DMA_INSPECT_MEMORY_COMMAND, address, length, callback, user_data));
 }
 
 gboolean
-dma_queue_disassemble (DmaDebuggerQueue *self, guint address, guint length, IAnjutaDebuggerCallback callback , gpointer user_data)
+dma_queue_disassemble (DmaDebuggerQueue *self, gulong address, guint length, IAnjutaDebuggerCallback callback , gpointer user_data)
 {
 	return dma_debugger_queue_append (self, dma_command_new (DMA_DISASSEMBLE_COMMAND, address, length, callback, user_data));
 }
@@ -1067,7 +1069,7 @@
 dma_command_run (DmaQueueCommand *cmd, IAnjutaDebugger *debugger,
 				 DmaDebuggerQueue *queue, GError **err)
 {
-	IAnjutaDebuggerRegister reg;
+	IAnjutaDebuggerRegisterData reg;
 	gboolean ret = FALSE;
 	DmaDebuggerCommandType type = cmd->type & COMMAND_MASK;
 	IAnjutaDebuggerCallback callback = cmd->callback == NULL ? NULL : dma_debugger_queue_command_callback;
@@ -1114,13 +1116,13 @@
 		ret = ianjuta_debugger_step_out (debugger, err);	
 		break;
 	case RUN_TO_ADDRESS_COMMAND:
-		ret = ianjuta_cpu_debugger_run_to_address (IANJUTA_CPU_DEBUGGER (debugger), cmd->data.pos.address, err);	
+		ret = ianjuta_debugger_instruction_run_to_address (IANJUTA_DEBUGGER_INSTRUCTION (debugger), cmd->data.pos.address, err);	
 		break;
 	case STEPI_IN_COMMAND:
-		ret = ianjuta_cpu_debugger_stepi_in (IANJUTA_CPU_DEBUGGER (debugger), err);	
+		ret = ianjuta_debugger_instruction_step_in (IANJUTA_DEBUGGER_INSTRUCTION (debugger), err);	
 		break;
 	case STEPI_OVER_COMMAND:
-		ret = ianjuta_cpu_debugger_stepi_over (IANJUTA_CPU_DEBUGGER (debugger), err);	
+		ret = ianjuta_debugger_instruction_step_over (IANJUTA_DEBUGGER_INSTRUCTION (debugger), err);	
 		break;
 	case EXIT_COMMAND:
 		ret = ianjuta_debugger_exit (debugger, err);	
@@ -1204,22 +1206,22 @@
 		ret = ianjuta_debugger_list_frame (debugger, callback, queue, err);	
 		break;
 	case LIST_REGISTER_COMMAND:
-		ret = ianjuta_cpu_debugger_list_register (IANJUTA_CPU_DEBUGGER (debugger), callback, queue, err);	
+		ret = ianjuta_debugger_register_list (IANJUTA_DEBUGGER_REGISTER (debugger), callback, queue, err);	
 		break;
 	case UPDATE_REGISTER_COMMAND:
-		ret = ianjuta_cpu_debugger_update_register (IANJUTA_CPU_DEBUGGER (debugger), callback, queue, err);	
+		ret = ianjuta_debugger_register_update (IANJUTA_DEBUGGER_REGISTER (debugger), callback, queue, err);	
 		break;
 	case WRITE_REGISTER_COMMAND:
 		reg.num = cmd->data.watch.id;
 	    reg.name = cmd->data.watch.name;
 	    reg.value = cmd->data.watch.value;
-		ret = ianjuta_cpu_debugger_write_register (IANJUTA_CPU_DEBUGGER (debugger), &reg, err);	
+		ret = ianjuta_debugger_register_write (IANJUTA_DEBUGGER_REGISTER (debugger), &reg, err);	
 		break;
 	case INSPECT_MEMORY_COMMAND:
-		ret = ianjuta_cpu_debugger_inspect_memory (IANJUTA_CPU_DEBUGGER (debugger), cmd->data.mem.address, cmd->data.mem.length, callback, queue, err);	
+		ret = ianjuta_debugger_memory_inspect (IANJUTA_DEBUGGER_MEMORY (debugger), cmd->data.mem.address, cmd->data.mem.length, callback, queue, err);	
 		break;
 	case DISASSEMBLE_COMMAND:
-		ret = ianjuta_cpu_debugger_disassemble (IANJUTA_CPU_DEBUGGER (debugger), cmd->data.mem.address, cmd->data.mem.length, callback, queue, err);	
+		ret = ianjuta_debugger_instruction_disassemble (IANJUTA_DEBUGGER_INSTRUCTION (debugger), cmd->data.mem.address, cmd->data.mem.length, callback, queue, err);	
 		break;
 	case USER_COMMAND:
 		ret = ianjuta_debugger_send_command (debugger, cmd->data.user.cmd, err);	

Modified: trunk/plugins/debug-manager/command.h
==============================================================================
--- trunk/plugins/debug-manager/command.h	(original)
+++ trunk/plugins/debug-manager/command.h	Fri Jan 18 20:40:36 2008
@@ -26,6 +26,7 @@
 #include "plugin.h"
 
 #include <libanjuta/interfaces/ianjuta-debugger.h>
+#include <libanjuta/interfaces/ianjuta-debugger-register.h>
 
 #include <glib.h>
 
@@ -68,7 +69,7 @@
 gboolean dma_queue_run_to (DmaDebuggerQueue *self, const gchar *file, gint line);
 gboolean dma_queue_stepi_in (DmaDebuggerQueue *self);
 gboolean dma_queue_stepi_over (DmaDebuggerQueue *self);
-gboolean dma_queue_run_to_address (DmaDebuggerQueue *self, guint address);
+gboolean dma_queue_run_to_address (DmaDebuggerQueue *self, gulong address);
 gboolean dma_queue_step_out (DmaDebuggerQueue *self);
 gboolean dma_queue_exit (DmaDebuggerQueue *self);
 gboolean dma_queue_interrupt (DmaDebuggerQueue *self);
@@ -98,7 +99,7 @@
 void dma_queue_disable_log (DmaDebuggerQueue *self);
 gboolean dma_queue_add_breakpoint_at_line (DmaDebuggerQueue *self, const gchar* file, guint line, IAnjutaDebuggerCallback callback, gpointer user_data);
 gboolean dma_queue_add_breakpoint_at_function (DmaDebuggerQueue *self, const gchar* file, const gchar* function, IAnjutaDebuggerCallback callback, gpointer user_data);
-gboolean dma_queue_add_breakpoint_at_address (DmaDebuggerQueue *self, guint address, IAnjutaDebuggerCallback callback, gpointer user_data);
+gboolean dma_queue_add_breakpoint_at_address (DmaDebuggerQueue *self, gulong address, IAnjutaDebuggerCallback callback, gpointer user_data);
 gboolean dma_queue_enable_breakpoint (DmaDebuggerQueue *self, guint id, gboolean enable, IAnjutaDebuggerCallback callback, gpointer user_data);
 gboolean dma_queue_ignore_breakpoint (DmaDebuggerQueue *self, guint id, guint ignore, IAnjutaDebuggerCallback callback, gpointer user_data);
 gboolean dma_queue_condition_breakpoint (DmaDebuggerQueue *self, guint id, const gchar *condition, IAnjutaDebuggerCallback callback, gpointer user_data);
@@ -106,9 +107,9 @@
 gboolean dma_queue_list_breakpoint (DmaDebuggerQueue *self, IAnjutaDebuggerCallback callback, gpointer user_data);
 gboolean dma_queue_list_register (DmaDebuggerQueue *self, IAnjutaDebuggerCallback callback, gpointer user_data);
 gboolean dma_queue_update_register (DmaDebuggerQueue *self, IAnjutaDebuggerCallback callback , gpointer user_data);
-gboolean dma_queue_write_register (DmaDebuggerQueue *self, IAnjutaDebuggerRegister *value);
-gboolean dma_queue_inspect_memory (DmaDebuggerQueue *self, guint address, guint length, IAnjutaDebuggerCallback callback , gpointer user_data);
-gboolean dma_queue_disassemble (DmaDebuggerQueue *self, guint address, guint length, IAnjutaDebuggerCallback callback , gpointer user_data);
+gboolean dma_queue_write_register (DmaDebuggerQueue *self, IAnjutaDebuggerRegisterData *value);
+gboolean dma_queue_inspect_memory (DmaDebuggerQueue *self, gulong address, guint length, IAnjutaDebuggerCallback callback , gpointer user_data);
+gboolean dma_queue_disassemble (DmaDebuggerQueue *self, gulong address, guint length, IAnjutaDebuggerCallback callback , gpointer user_data);
 gboolean dma_queue_delete_variable (DmaDebuggerQueue *self, const gchar *name);
 gboolean dma_queue_evaluate_variable (DmaDebuggerQueue *self, const gchar *name, IAnjutaDebuggerCallback callback, gpointer user_data);
 gboolean dma_queue_assign_variable (DmaDebuggerQueue *self, const gchar *name, const gchar *value);

Modified: trunk/plugins/debug-manager/disassemble.c
==============================================================================
--- trunk/plugins/debug-manager/disassemble.c	(original)
+++ trunk/plugins/debug-manager/disassemble.c	Fri Jan 18 20:40:36 2008
@@ -95,7 +95,7 @@
 
 struct _DmaDisassemblyLine
 {
-	guint address;
+	gulong address;
 	gchar* text;
 };
 
@@ -388,7 +388,7 @@
 }
 
 static void
-on_disassemble (const IAnjutaDebuggerDisassembly *block, DmaSparseBufferTransport *trans, GError *err)
+on_disassemble (const IAnjutaDebuggerInstructionDisassembly *block, DmaSparseBufferTransport *trans, GError *err)
 {
 	DmaDisassemblyBufferNode *node;
 	DmaDisassemblyBuffer *buffer = (DmaDisassemblyBuffer *)trans->buffer;
@@ -790,7 +790,7 @@
 }
 
 static void
-on_program_moved (DmaDisassemble *self, guint pid, guint tid, guint address, const gchar* file, guint line)
+on_program_moved (DmaDisassemble *self, guint pid, guint tid, gulong address, const gchar* file, guint line)
 {
 	dma_sparse_view_delete_all_markers (self->view, IANJUTA_MARKABLE_PROGRAM_COUNTER);	
 	
@@ -802,7 +802,7 @@
 }
 
 static void
-on_location_changed (DmaDisassemble *self, guint address, const gchar* uri, guint line)
+on_location_changed (DmaDisassemble *self, gulong address, const gchar* uri, guint line)
 {
 	dma_sparse_view_goto (self->view, address);
 }
@@ -859,7 +859,7 @@
 static void
 on_program_loaded (DmaDisassemble *self)
 {
-	if (!dma_debugger_queue_is_supported (self->debugger, HAS_CPU)) return;
+	if (!dma_debugger_queue_is_supported (self->debugger, HAS_INSTRUCTION)) return;
 
 	if (!create_disassemble_gui (self)) return;
 

Modified: trunk/plugins/debug-manager/disassemble.h
==============================================================================
--- trunk/plugins/debug-manager/disassemble.h	(original)
+++ trunk/plugins/debug-manager/disassemble.h	Fri Jan 18 20:40:36 2008
@@ -27,7 +27,7 @@
 
 #include <libanjuta/anjuta-plugin.h>
 #include <libanjuta/interfaces/ianjuta-debugger.h>
-#include <libanjuta/interfaces/ianjuta-cpu-debugger.h>
+#include <libanjuta/interfaces/ianjuta-debugger-instruction.h>
 
 typedef struct _DmaDisassemble DmaDisassemble;
 

Modified: trunk/plugins/debug-manager/memory.c
==============================================================================
--- trunk/plugins/debug-manager/memory.c	(original)
+++ trunk/plugins/debug-manager/memory.c	Fri Jan 18 20:40:36 2008
@@ -56,7 +56,7 @@
  *---------------------------------------------------------------------------*/
 
 static void
-on_memory_block_read (const IAnjutaDebuggerMemory *block, DmaMemory *mem, GError *err)
+on_memory_block_read (const IAnjutaDebuggerMemoryBlock *block, DmaMemory *mem, GError *err)
 {
 	const gchar* tag;
 	
@@ -68,7 +68,7 @@
 	
 	guint length = block->length;
 	gchar *data = block->data;
-	guint address = block->address;
+	gulong address = block->address;
 	
 	tag = data + length;
 	while (length != 0)
@@ -105,7 +105,7 @@
 	{	
 		dma_queue_inspect_memory (
 				mem->debugger,
-				(guint)address,
+				address,
 				(guint)length,
 				(IAnjutaDebuggerCallback)on_memory_block_read,
 				mem);
@@ -189,7 +189,7 @@
 	 * unloading a program in the debugger */
 	if (mem->window) return;
 	
-	if (!dma_debugger_queue_is_supported (mem->debugger, HAS_CPU)) return;
+	if (!dma_debugger_queue_is_supported (mem->debugger, HAS_MEMORY)) return;
 
 	if (!create_memory_gui (mem)) return;
 

Modified: trunk/plugins/debug-manager/memory.h
==============================================================================
--- trunk/plugins/debug-manager/memory.h	(original)
+++ trunk/plugins/debug-manager/memory.h	Fri Jan 18 20:40:36 2008
@@ -27,7 +27,7 @@
 
 #include <libanjuta/anjuta-plugin.h>
 #include <libanjuta/interfaces/ianjuta-debugger.h>
-#include <libanjuta/interfaces/ianjuta-cpu-debugger.h>
+#include <libanjuta/interfaces/ianjuta-debugger-memory.h>
 
 typedef struct _DmaMemory DmaMemory;
 

Modified: trunk/plugins/debug-manager/plugin.c
==============================================================================
--- trunk/plugins/debug-manager/plugin.c	(original)
+++ trunk/plugins/debug-manager/plugin.c	Fri Jan 18 20:40:36 2008
@@ -85,7 +85,7 @@
 	guint editor_watch_id;
 	IAnjutaEditor *pc_editor;
 	guint pc_line;
-	guint pc_address;
+	gulong pc_address;
 	gboolean busy;
 	
 	/* Debugger components */
@@ -185,7 +185,7 @@
 }
 
 static void
-set_program_counter(DebugManagerPlugin *self, const gchar* file, guint line, guint address)
+set_program_counter(DebugManagerPlugin *self, const gchar* file, guint line, gulong address)
 {
 	IAnjutaDocumentManager *docman = NULL;
 	gchar *file_uri;
@@ -456,9 +456,9 @@
 /* Called when the program postion change */
 
 static void
-dma_plugin_program_moved (DebugManagerPlugin *this, guint pid, guint tid, guint address, const gchar* file, guint line)
+dma_plugin_program_moved (DebugManagerPlugin *this, guint pid, guint tid, gulong address, const gchar* file, guint line)
 {
-	DEBUG_PRINT ("DMA: dma_plugin_program_moved %s %d %x", file, line, address);
+	DEBUG_PRINT ("DMA: dma_plugin_program_moved %s %d %lx", file, line, address);
 
 	set_program_counter (this, file, line, address);
 }
@@ -556,7 +556,7 @@
 /* Called when the user want to go to another location */
 
 static void
-dma_plugin_location_changed (DebugManagerPlugin *self, guint address, const gchar* uri, guint line)
+dma_plugin_location_changed (DebugManagerPlugin *self, gulong address, const gchar* uri, guint line)
 {
 	/* Go to location in editor */
 	if (uri != NULL)
@@ -672,7 +672,7 @@
 	{
 		if ((plugin->disassemble != NULL) && (dma_disassemble_is_focus (plugin->disassemble)))
 		{
-			guint address;
+			gulong address;
 			
 			address = dma_disassemble_get_current_address (plugin->disassemble);
 			dma_queue_run_to_address (plugin->queue, address);

Modified: trunk/plugins/debug-manager/queue.c
==============================================================================
--- trunk/plugins/debug-manager/queue.h	(original)
+++ trunk/plugins/debug-manager/queue.h	Fri Jan 18 20:40:36 2008
@@ -35,7 +35,6 @@
 
 typedef enum
 {
-	HAS_CPU = 1 << 0,
 	HAS_BREAKPOINT = 1 << 1,
 	HAS_ADDRESS_BREAKPOINT = IANJUTA_DEBUGGER_BREAKPOINT_SET_AT_ADDRESS * HAS_BREAKPOINT * 2,
 	HAS_FUNCTION_BREAKPOINT = IANJUTA_DEBUGGER_BREAKPOINT_SET_AT_FUNCTION  * HAS_BREAKPOINT * 2,
@@ -43,6 +42,9 @@
 	HAS_IGNORE_BREAKPOINT = IANJUTA_DEBUGGER_BREAKPOINT_IGNORE * HAS_BREAKPOINT * 2,
 	HAS_CONDITION_BREAKPOINT = IANJUTA_DEBUGGER_BREAKPOINT_CONDITION * HAS_BREAKPOINT * 2,
 	HAS_VARIABLE = 1 << 8,
+	HAS_REGISTER = 1 << 9,
+	HAS_MEMORY = 1 << 10,
+	HAS_INSTRUCTION = 1 << 11
 
 } DmaDebuggerCapability;
 

Modified: trunk/plugins/debug-manager/registers.c
==============================================================================
--- trunk/plugins/debug-manager/registers.c	(original)
+++ trunk/plugins/debug-manager/registers.c	Fri Jan 18 20:40:36 2008
@@ -137,7 +137,7 @@
 	
 	for(node = registers;node != NULL; node = g_list_next (node))
 	{
-		IAnjutaDebuggerRegister *reg = (IAnjutaDebuggerRegister *)node->data;
+		IAnjutaDebuggerRegisterData *reg = (IAnjutaDebuggerRegisterData *)node->data;
 		guint id;
 		gchar *value;
 		
@@ -350,7 +350,7 @@
 
 	if (gtk_tree_model_get_iter_from_string (self->current->model, &iter, path_string))
 	{
-		IAnjutaDebuggerRegister reg;
+		IAnjutaDebuggerRegisterData reg;
 		gchar *name;
 		
 		gtk_tree_model_get (self->current->model, &iter, NUMBER_COLUMN, &reg.num, NAME_COLUMN, &name, -1);
@@ -491,7 +491,7 @@
 static void
 on_program_started (CpuRegisters *self)
 {
-	if (!dma_debugger_queue_is_supported (self->debugger, HAS_CPU)) return;
+	if (!dma_debugger_queue_is_supported (self->debugger, HAS_REGISTER)) return;
 
 	/* If current debugger support access to cpu hardware */
 	if (!create_cpu_registers_gui (self)) return;

Modified: trunk/plugins/debug-manager/registers.h
==============================================================================
--- trunk/plugins/debug-manager/registers.h	(original)
+++ trunk/plugins/debug-manager/registers.h	Fri Jan 18 20:40:36 2008
@@ -25,7 +25,7 @@
 
 #include <libanjuta/anjuta-plugin.h>
 #include <libanjuta/interfaces/ianjuta-debugger.h>
-#include <libanjuta/interfaces/ianjuta-cpu-debugger.h>
+#include <libanjuta/interfaces/ianjuta-debugger-register.h>
 
 #include <gnome.h>
 

Modified: trunk/plugins/debug-manager/stack_trace.c
==============================================================================
--- trunk/plugins/debug-manager/stack_trace.c	(original)
+++ trunk/plugins/debug-manager/stack_trace.c	Fri Jan 18 20:40:36 2008
@@ -225,7 +225,7 @@
 			/* Check if it's the same stack frame */
 			gchar *adr;
 			gchar *args;
-			guint address;
+			gulong address;
 			guint line;
 			gboolean same;
 			
@@ -287,7 +287,7 @@
 					
 		gtk_list_store_prepend (model, &iter);
 
-		adr = g_strdup_printf ("0x%x", frame->address);
+		adr = g_strdup_printf ("0x%lx", frame->address);
 		if (frame->file)
 		{
 			uri = gnome_vfs_get_uri_from_local_path(frame->file);
@@ -481,7 +481,7 @@
 	gchar *uri;
 	guint line;
 	gchar *adr;
-	guint address;
+	gulong address;
 	
 	StackTrace* st = (StackTrace*) user_data;		
 
@@ -642,7 +642,7 @@
 	gtk_tree_view_column_set_title (column, _("Function"));
 	gtk_tree_view_append_column (st->treeview, column);
 	
-	if (dma_debugger_queue_is_supported (st->debugger, HAS_CPU))
+	if (dma_debugger_queue_is_supported (st->debugger, HAS_MEMORY))
 	{
 		/* Display address only if debugger has such concept */
 		column = gtk_tree_view_column_new ();

Modified: trunk/plugins/debug-manager/threads.c
==============================================================================
--- trunk/plugins/debug-manager/threads.c	(original)
+++ trunk/plugins/debug-manager/threads.c	Fri Jan 18 20:40:36 2008
@@ -156,7 +156,7 @@
 	gchar *uri;
 	guint line;
 	gchar *adr;
-	guint address;
+	gulong address;
 	DmaThreads* self = (DmaThreads*) user_data;		
 
 	view = self->list;
@@ -217,7 +217,7 @@
 	
 	if (frame == NULL) return;
 	
-	adr = g_strdup_printf ("0x%x", frame->address);
+	adr = g_strdup_printf ("0x%lx", frame->address);
 	
 	if (frame->file)
 	{
@@ -289,7 +289,7 @@
 		else
 			pic = NULL;
 
-		if ((dma_debugger_queue_is_supported (self->debugger, HAS_CPU) && (frame->address == 0))
+		if ((dma_debugger_queue_is_supported (self->debugger, HAS_MEMORY) && (frame->address == 0))
 			|| (frame->function == NULL))
 		{
 			/* Missing frame address, request more information */
@@ -312,7 +312,7 @@
 		}
 		else
 		{
-			adr = g_strdup_printf ("0x%x", frame->address);
+			adr = g_strdup_printf ("0x%lx", frame->address);
 			if (frame->file)
 			{
 				uri = gnome_vfs_get_uri_from_local_path(frame->file);
@@ -449,7 +449,7 @@
 	gtk_tree_view_column_set_title (column, _("Function"));
 	gtk_tree_view_append_column (self->list, column);
 	
-	if (dma_debugger_queue_is_supported (self->debugger, HAS_CPU))
+	if (dma_debugger_queue_is_supported (self->debugger, HAS_MEMORY))
 	{
 		/* Display address only if debugger has such concept */
 		column = gtk_tree_view_column_new ();

Modified: trunk/plugins/gdb/anjuta-gdb.plugin.in
==============================================================================
--- trunk/plugins/gdb/anjuta-gdb.plugin.in	(original)
+++ trunk/plugins/gdb/anjuta-gdb.plugin.in	Fri Jan 18 20:40:36 2008
@@ -4,7 +4,7 @@
 Location=anjuta-gdb:GdbPlugin
 Icon=anjuta-gdb.plugin.png
 UserActivatable=no
-Interfaces=IAnjutaDebugger,IAnjutaCpuDebugger
+Interfaces=IAnjutaDebugger
 
 [File Loader]
 SupportedMimeTypes=application/x-executable,application/x-core,application/x-shellscript

Modified: trunk/plugins/gdb/debugger.c
==============================================================================
--- trunk/plugins/gdb/debugger.c	(original)
+++ trunk/plugins/gdb/debugger.c	Fri Jan 18 20:40:36 2008
@@ -39,6 +39,10 @@
 #include <libanjuta/anjuta-launcher.h>
 #include <libanjuta/anjuta-debug.h>
 #include <libanjuta/anjuta-marshal.h>
+#include <libanjuta/interfaces/ianjuta-debugger-breakpoint.h>
+#include <libanjuta/interfaces/ianjuta-debugger-register.h>
+#include <libanjuta/interfaces/ianjuta-debugger-memory.h>
+#include <libanjuta/interfaces/ianjuta-debugger-instruction.h>
 #include <libanjuta/interfaces/ianjuta-debugger-variable.h>
 
 #include "debugger.h"
@@ -1676,7 +1680,7 @@
 
 void
 debugger_program_moved (Debugger *debugger, const gchar *file,
-						  gint line, guint address)
+						  gint line, gulong address)
 {
 	gchar *src_path;
 	
@@ -2039,7 +2043,7 @@
 }
 
 void
-debugger_run_to_address (Debugger *debugger, guint address)
+debugger_run_to_address (Debugger *debugger, gulong address)
 {
 	gchar *buff;
 
@@ -2048,7 +2052,7 @@
 	g_return_if_fail (IS_DEBUGGER (debugger));
 	g_return_if_fail (debugger->priv->prog_is_running == TRUE);
 	
-	buff = g_strdup_printf ("-break-insert -t *0x%x", address);
+	buff = g_strdup_printf ("-break-insert -t *0x%lx", address);
 	debugger_queue_command (debugger, buff, FALSE, FALSE, NULL, NULL, NULL);
 	g_free (buff);
 	debugger_queue_command (debugger, "-exec-continue", FALSE, FALSE, NULL, NULL, NULL);
@@ -2192,7 +2196,7 @@
 }
 
 void
-debugger_add_breakpoint_at_address (Debugger *debugger, guint address, IAnjutaDebuggerCallback callback, gpointer user_data)
+debugger_add_breakpoint_at_address (Debugger *debugger, gulong address, IAnjutaDebuggerCallback callback, gpointer user_data)
 {
 	gchar *buff;
 
@@ -2200,7 +2204,7 @@
 
 	g_return_if_fail (IS_DEBUGGER (debugger));
 
-	buff = g_strdup_printf ("-break-insert *0x%x", address);
+	buff = g_strdup_printf ("-break-insert *0x%lx", address);
 	debugger_queue_command (debugger, buff, FALSE, FALSE, debugger_add_breakpoint_finish, callback, user_data);
 	g_free (buff);
 }
@@ -2652,12 +2656,12 @@
 	const gchar *value;
 	gchar *data;
 	gchar *ptr;
-	guint address;
+	gulong address;
 	guint len;
 	guint i;
 	IAnjutaDebuggerCallback callback = debugger->priv->current_cmd.callback;
 	gpointer user_data = debugger->priv->current_cmd.user_data;
-	IAnjutaDebuggerMemory read = {0,};
+	IAnjutaDebuggerMemoryBlock read = {0,};
 
 	literal = gdbmi_value_hash_lookup (mi_results, "total-bytes");
 	if (literal)
@@ -2718,7 +2722,7 @@
 }
 
 void
-debugger_inspect_memory (Debugger *debugger, guint address, guint length, IAnjutaDebuggerCallback callback, gpointer user_data)
+debugger_inspect_memory (Debugger *debugger, gulong address, guint length, IAnjutaDebuggerCallback callback, gpointer user_data)
 {
 	gchar *buff;
 	
@@ -2726,7 +2730,7 @@
 
 	g_return_if_fail (IS_DEBUGGER (debugger));
 
-	buff = g_strdup_printf ("-data-read-memory 0x%x x 1 1 %d", address, length);
+	buff = g_strdup_printf ("-data-read-memory 0x%lx x 1 1 %d", address, length);
 	debugger_queue_command (debugger, buff, FALSE, FALSE, debugger_read_memory_finish, callback, user_data);
 	g_free (buff);
 }
@@ -2742,7 +2746,7 @@
 	guint i;
 	IAnjutaDebuggerCallback callback = debugger->priv->current_cmd.callback;
 	gpointer user_data = debugger->priv->current_cmd.user_data;
-	IAnjutaDebuggerDisassembly *read = NULL;
+	IAnjutaDebuggerInstructionDisassembly *read = NULL;
 
 	if (error != NULL)
 	{
@@ -2759,7 +2763,7 @@
 		guint size;
 	
 		size = gdbmi_value_get_size (mem);
-		read = (IAnjutaDebuggerDisassembly *)g_malloc0(sizeof (IAnjutaDebuggerDisassembly) + sizeof(IAnjutaDebuggerALine) * size);
+		read = (IAnjutaDebuggerInstructionDisassembly *)g_malloc0(sizeof (IAnjutaDebuggerInstructionDisassembly) + sizeof(IAnjutaDebuggerInstructionALine) * size);
 		read->size = size;
 
 		for (i = 0; i < size; i++)
@@ -2815,9 +2819,10 @@
 }
 
 void
-debugger_disassemble (Debugger *debugger, guint address, guint length, IAnjutaDebuggerCallback callback, gpointer user_data)
+debugger_disassemble (Debugger *debugger, gulong address, guint length, IAnjutaDebuggerCallback callback, gpointer user_data)
 {
 	gchar *buff;
+	gulong end;
 	
 	DEBUG_PRINT ("In function: debugger_disassemble()");
 
@@ -2825,8 +2830,8 @@
 
 
 	/* Handle overflow */
-	if (address + length < address) length = G_MAXUINT - address;
-	buff = g_strdup_printf ("-data-disassemble -s 0x%x -e 0x%x  -- 0", address, address + length);
+	end = (address + length < address) ? G_MAXULONG : address + length;
+	buff = g_strdup_printf ("-data-disassemble -s 0x%lx -e 0x%lx  -- 0", address, end);
 	debugger_queue_command (debugger, buff, FALSE, FALSE, debugger_disassemble_finish, callback, user_data);
 	g_free (buff);
 }
@@ -3188,13 +3193,13 @@
 static void
 add_register_name (const GDBMIValue *reg_literal, GList** list)
 {
-	IAnjutaDebuggerRegister* reg;
+	IAnjutaDebuggerRegisterData* reg;
 	GList *prev = *list;
 	
-	reg = g_new0 (IAnjutaDebuggerRegister, 1);
+	reg = g_new0 (IAnjutaDebuggerRegisterData, 1);
 	*list = g_list_prepend (prev, reg);
 	reg->name = (gchar *)gdbmi_value_literal_get (reg_literal);
-	reg->num = prev == NULL ? 0 : ((IAnjutaDebuggerRegister *)prev->data)->num + 1;
+	reg->num = prev == NULL ? 0 : ((IAnjutaDebuggerRegisterData *)prev->data)->num + 1;
 }
 
 static void
@@ -3202,7 +3207,7 @@
 {
 	const GDBMIValue *literal;
 	const gchar *val;
-	IAnjutaDebuggerRegister* reg;
+	IAnjutaDebuggerRegisterData* reg;
 	guint num;
 	GList* prev = *list;
 		
@@ -3216,7 +3221,7 @@
 	if (!literal)
 		return;
 	
-	reg = g_new0 (IAnjutaDebuggerRegister, 1);
+	reg = g_new0 (IAnjutaDebuggerRegisterData, 1);
 	*list = g_list_prepend (prev, reg);
 	reg->num = num;
 	reg->value = (gchar *)gdbmi_value_literal_get (literal);

Modified: trunk/plugins/gdb/debugger.h
==============================================================================
--- trunk/plugins/gdb/debugger.h	(original)
+++ trunk/plugins/gdb/debugger.h	Fri Jan 18 20:40:36 2008
@@ -27,7 +27,6 @@
 
 #include <libanjuta/interfaces/ianjuta-message-view.h>
 #include <libanjuta/interfaces/ianjuta-debugger.h>
-#include <libanjuta/interfaces/ianjuta-cpu-debugger.h>
 
 G_BEGIN_DECLS
 
@@ -99,7 +98,7 @@
 					   gpointer user_data);
 
 void debugger_program_moved (Debugger *debugger, const gchar *file,
-							   gint line, guint address);
+							   gint line, gulong address);
 gchar* debugger_get_source_path (Debugger *debugger, const gchar *file);
 
 /* Program loading */
@@ -121,12 +120,12 @@
 void debugger_stepi_over (Debugger *debugger);
 void debugger_run_to_location (Debugger *debugger, const gchar *loc);
 void debugger_run_to_position (Debugger *debugger, const gchar *file, guint line);
-void debugger_run_to_address (Debugger *debugger, guint address);
+void debugger_run_to_address (Debugger *debugger, gulong address);
 
 /* Breakpoint */
 void debugger_add_breakpoint_at_line (Debugger *debugger, const gchar* file, guint line, IAnjutaDebuggerCallback callback, gpointer user_data);
 void debugger_add_breakpoint_at_function (Debugger *debugger, const gchar* file, const gchar* function, IAnjutaDebuggerCallback callback, gpointer user_data);
-void debugger_add_breakpoint_at_address (Debugger *debugger, guint address, IAnjutaDebuggerCallback callback, gpointer user_data);
+void debugger_add_breakpoint_at_address (Debugger *debugger, gulong address, IAnjutaDebuggerCallback callback, gpointer user_data);
 void debugger_remove_breakpoint (Debugger *debugger, guint id, IAnjutaDebuggerCallback callback, gpointer user_data);
 void debugger_list_breakpoint (Debugger *debugger, IAnjutaDebuggerCallback callback, gpointer user_data);
 void debugger_enable_breakpoint (Debugger *debugger, guint id, gboolean enable, IAnjutaDebuggerCallback callback, gpointer user_data);
@@ -148,8 +147,8 @@
 void debugger_info_program (Debugger *debugger, IAnjutaDebuggerCallback func, gpointer user_data);
 void debugger_info_udot (Debugger *debugger, IAnjutaDebuggerCallback func, gpointer user_data);
 void debugger_info_variables (Debugger *debugger, IAnjutaDebuggerCallback func, gpointer user_data);
-void debugger_inspect_memory (Debugger *debugger, guint address, guint length, IAnjutaDebuggerCallback func, gpointer user_data);
-void debugger_disassemble (Debugger *debugger, guint address, guint length, IAnjutaDebuggerCallback func, gpointer user_data);
+void debugger_inspect_memory (Debugger *debugger, gulong address, guint length, IAnjutaDebuggerCallback func, gpointer user_data);
+void debugger_disassemble (Debugger *debugger, gulong address, guint length, IAnjutaDebuggerCallback func, gpointer user_data);
 
 /* Register */
 

Modified: trunk/plugins/gdb/plugin.c
==============================================================================
--- trunk/plugins/gdb/plugin.c	(original)
+++ trunk/plugins/gdb/plugin.c	Fri Jan 18 20:40:36 2008
@@ -33,7 +33,9 @@
 
 #include <libanjuta/interfaces/ianjuta-debugger.h>
 #include <libanjuta/interfaces/ianjuta-debugger-breakpoint.h>
-#include <libanjuta/interfaces/ianjuta-cpu-debugger.h>
+#include <libanjuta/interfaces/ianjuta-debugger-register.h>
+#include <libanjuta/interfaces/ianjuta-debugger-memory.h>
+#include <libanjuta/interfaces/ianjuta-debugger-instruction.h>
 #include <libanjuta/interfaces/ianjuta-debugger-variable.h>
 #include <libanjuta/interfaces/ianjuta-terminal.h>
 #include <libanjuta/anjuta-plugin.h>
@@ -809,7 +811,7 @@
 }
 
 static gboolean
-idebugger_breakpoint_add_at_address (IAnjutaDebuggerBreakpoint *plugin, guint address, IAnjutaDebuggerCallback callback, gpointer user_data, GError **err)
+idebugger_breakpoint_add_at_address (IAnjutaDebuggerBreakpoint *plugin, gulong address, IAnjutaDebuggerCallback callback, gpointer user_data, GError **err)
 {
 	GdbPlugin *this = ANJUTA_PLUGIN_GDB (plugin);
 	
@@ -882,11 +884,11 @@
 	iface->condition = idebugger_breakpoint_condition;
 }
 
-/* Implementation of IAnjutaCpuDebugger interface
+/* Implementation of IAnjutaDebuggerRegister interface
  *---------------------------------------------------------------------------*/
 
 static gboolean
-icpu_debugger_list_register (IAnjutaCpuDebugger *plugin, IAnjutaDebuggerCallback callback , gpointer user_data, GError **err)
+idebugger_register_list (IAnjutaDebuggerRegister *plugin, IAnjutaDebuggerCallback callback , gpointer user_data, GError **err)
 {
 	GdbPlugin *this = ANJUTA_PLUGIN_GDB (plugin);
 
@@ -896,7 +898,7 @@
 }
 
 static gboolean
-icpu_debugger_update_register (IAnjutaCpuDebugger *plugin, IAnjutaDebuggerCallback callback , gpointer user_data, GError **err)
+idebugger_register_update (IAnjutaDebuggerRegister *plugin, IAnjutaDebuggerCallback callback , gpointer user_data, GError **err)
 {
 	GdbPlugin *this = ANJUTA_PLUGIN_GDB (plugin);
 
@@ -906,7 +908,7 @@
 }
 
 static gboolean
-icpu_debugger_write_register (IAnjutaCpuDebugger *plugin, IAnjutaDebuggerRegister *value, GError **err)
+idebugger_register_write (IAnjutaDebuggerRegister *plugin, IAnjutaDebuggerRegisterData *value, GError **err)
 {
 	GdbPlugin *this = ANJUTA_PLUGIN_GDB (plugin);
 
@@ -915,8 +917,19 @@
 	return TRUE;
 }
 
+static void
+idebugger_register_iface_init (IAnjutaDebuggerRegisterIface *iface)
+{
+	iface->list = idebugger_register_list;
+	iface->update = idebugger_register_update;
+	iface->write = idebugger_register_write;
+}
+
+/* Implementation of IAnjutaDebuggerMemory interface
+ *---------------------------------------------------------------------------*/
+
 static gboolean
-icpu_debugger_inspect_memory (IAnjutaCpuDebugger *plugin, guint address, guint length, IAnjutaDebuggerCallback callback , gpointer user_data, GError **err)
+idebugger_memory_inspect (IAnjutaDebuggerMemory *plugin, gulong address, guint length, IAnjutaDebuggerCallback callback , gpointer user_data, GError **err)
 {
 	GdbPlugin *this = ANJUTA_PLUGIN_GDB (plugin);
 
@@ -925,8 +938,17 @@
 	return TRUE;
 }
 
+static void
+idebugger_memory_iface_init (IAnjutaDebuggerMemoryIface *iface)
+{
+	iface->inspect = idebugger_memory_inspect;
+}
+
+/* Implementation of IAnjutaDebuggerInstruction interface
+ *---------------------------------------------------------------------------*/
+
 static gboolean
-icpu_debugger_disassemble (IAnjutaCpuDebugger *plugin, guint address, guint length, IAnjutaDebuggerCallback callback , gpointer user_data, GError **err)
+idebugger_instruction_disassemble (IAnjutaDebuggerInstruction *plugin, gulong address, guint length, IAnjutaDebuggerCallback callback , gpointer user_data, GError **err)
 {
 	GdbPlugin *this = (GdbPlugin *)plugin;
 
@@ -936,7 +958,7 @@
 }
 
 static gboolean
-icpu_debugger_stepi_in (IAnjutaCpuDebugger *plugin, GError **err)
+idebugger_instruction_step_in (IAnjutaDebuggerInstruction *plugin, GError **err)
 {
 	GdbPlugin *this = ANJUTA_PLUGIN_GDB (plugin);
 	
@@ -946,7 +968,7 @@
 }
 
 static gboolean
-icpu_debugger_stepi_over (IAnjutaCpuDebugger *plugin, GError **err)
+idebugger_instruction_step_over (IAnjutaDebuggerInstruction *plugin, GError **err)
 {
 	GdbPlugin *this = ANJUTA_PLUGIN_GDB (plugin);
 	
@@ -956,7 +978,7 @@
 }
 
 static gboolean
-icpu_debugger_run_to_address (IAnjutaCpuDebugger *plugin, guint address, GError **err)
+idebugger_instruction_run_to_address (IAnjutaDebuggerInstruction *plugin, gulong address, GError **err)
 {
 	GdbPlugin *this = ANJUTA_PLUGIN_GDB (plugin);
 	
@@ -966,16 +988,12 @@
 }
 
 static void
-icpu_debugger_iface_init (IAnjutaCpuDebuggerIface *iface)
+idebugger_instruction_iface_init (IAnjutaDebuggerInstructionIface *iface)
 {
-	iface->list_register = icpu_debugger_list_register;
-	iface->update_register = icpu_debugger_update_register;
-	iface->write_register = icpu_debugger_write_register;
-	iface->inspect_memory = icpu_debugger_inspect_memory;
-	iface->disassemble = icpu_debugger_disassemble;
-	iface->stepi_in = icpu_debugger_stepi_in;
-	iface->stepi_over = icpu_debugger_stepi_over;
-	iface->run_to_address = icpu_debugger_run_to_address;
+	iface->disassemble = idebugger_instruction_disassemble;
+	iface->step_in = idebugger_instruction_step_in;
+	iface->step_over = idebugger_instruction_step_over;
+	iface->run_to_address = idebugger_instruction_run_to_address;
 }
 
 /* Implementation of IAnjutaDebuggerVariable interface
@@ -1055,7 +1073,9 @@
 ANJUTA_PLUGIN_BEGIN (GdbPlugin, gdb_plugin);
 ANJUTA_PLUGIN_ADD_INTERFACE(idebugger, IANJUTA_TYPE_DEBUGGER);
 ANJUTA_PLUGIN_ADD_INTERFACE(idebugger_breakpoint, IANJUTA_TYPE_DEBUGGER_BREAKPOINT);
-ANJUTA_PLUGIN_ADD_INTERFACE(icpu_debugger, IANJUTA_TYPE_CPU_DEBUGGER);
+ANJUTA_PLUGIN_ADD_INTERFACE(idebugger_register, IANJUTA_TYPE_DEBUGGER_REGISTER);
+ANJUTA_PLUGIN_ADD_INTERFACE(idebugger_memory, IANJUTA_TYPE_DEBUGGER_MEMORY);
+ANJUTA_PLUGIN_ADD_INTERFACE(idebugger_instruction, IANJUTA_TYPE_DEBUGGER_INSTRUCTION);
 ANJUTA_PLUGIN_ADD_INTERFACE(idebugger_variable, IANJUTA_TYPE_DEBUGGER_VARIABLE);
 ANJUTA_PLUGIN_END;
 



[Date Prev][Date Next]   [Thread Prev][Thread Next]   [Thread Index] [Date Index] [Author Index]
--- trunk/plugins/debug-manager/queue.c	(original)
+++ trunk/plugins/debug-manager/queue.c	Fri Jan 18 20:40:36 2008
@@ -30,7 +30,9 @@
 /*#define DEBUG*/
 #include <libanjuta/anjuta-debug.h>
 #include <libanjuta/interfaces/ianjuta-message-manager.h>
-#include <libanjuta/interfaces/ianjuta-cpu-debugger.h>
+#include <libanjuta/interfaces/ianjuta-debugger-register.h>
+#include <libanjuta/interfaces/ianjuta-debugger-memory.h>
+#include <libanjuta/interfaces/ianjuta-debugger-instruction.h>
 #include <libanjuta/interfaces/ianjuta-debugger-breakpoint.h>
 #include <libanjuta/interfaces/ianjuta-debugger-variable.h>
 
@@ -563,8 +565,12 @@
 		self->debugger = (IAnjutaDebugger *)anjuta_plugin_manager_get_plugin_by_id (plugin_manager, value);
 
 		self->support = 0;
-		/* Check if cpu interface is available */
-		self->support |= IANJUTA_IS_CPU_DEBUGGER(self->debugger) ? HAS_CPU : 0;
+		/* Check if register interface is available */
+		self->support |= IANJUTA_IS_DEBUGGER_REGISTER(self->debugger) ? HAS_REGISTER : 0;
+		/* Check if memory interface is available */
+		self->support |= IANJUTA_IS_DEBUGGER_MEMORY(self->debugger) ? HAS_MEMORY : 0;
+		/* Check if instruction interface is available */
+		self->support |= IANJUTA_IS_DEBUGGER_INSTRUCTION(self->debugger) ? HAS_INSTRUCTION : 0;
 		/* Check if breakpoint interface is available */
 		self->support |= IANJUTA_IS_DEBUGGER_BREAKPOINT(self->debugger) ? HAS_BREAKPOINT : 0;
 		if (IANJUTA_IS_DEBUGGER_BREAKPOINT (self->debugger))
@@ -646,7 +652,7 @@
 }
 
 static void
-on_dma_program_moved (DmaDebuggerQueue *self, guint pid, gint tid, guint address, const gchar* src_path, guint line)
+on_dma_program_moved (DmaDebuggerQueue *self, guint pid, gint tid, gulong address, const gchar* src_path, guint line)
 {
 	DEBUG_PRINT ("From debugger: program moved");
 	self->prepend_command++;

Modified: trunk/plugins/debug-manager/queue.h
==============================================================================